<?php
/**
 * Created by PhpStorm.
 * User: phuongth
 * Date: 7/16/2016
 * Time: 3:23 PM
 */

if (!defined('ABSPATH')) die('-1');

if (!defined('GF_GALLERY_CATEGORY_TAXONOMY'))
    define('GF_GALLERY_CATEGORY_TAXONOMY', 'gf-gallery-category');

if (!defined('GF_GALLERY_POST_TYPE'))
    define('GF_GALLERY_POST_TYPE', 'gf-gallery');

if (!defined('GF_GALLERY_DIR_PATH'))
    define('GF_GALLERY_DIR_PATH', plugin_dir_path(__FILE__));

if (!class_exists('GF_FrameWork_Gallery')) {
    class GF_FrameWork_Gallery
    {
        function __construct(){
            add_action('init', array($this, 'register_taxonomies'), 5);
            add_action('init', array($this, 'register_post_types'), 6);
            add_filter('rwmb_meta_boxes', array($this, 'register_meta_boxes'));
        }

        function register_post_types()
        {

            $post_type = GF_GALLERY_POST_TYPE;

            if (post_type_exists($post_type)) {
                return;
            }

            $post_type_slug = get_option('gf-rica-' . $post_type . '-config');
            if (!isset($post_type_slug) || !is_array($post_type_slug)) {
                $slug = $post_type;
                $name = $singular_name = 'Gallery';
            } else {
                $slug = $post_type_slug['slug'];
                $name = $post_type_slug['name'];
                $singular_name = $post_type_slug['singular_name'];
            }

            register_post_type($post_type,
                array(
                    'label' => esc_html__('Rica Gallery', 'rica'),
                    'description' => esc_html__('Gallery Description', 'rica'),
                    'labels' => array(
                        'name' => $name,
                        'singular_name' => $singular_name,
                        'menu_name' => ucfirst($name),
                        'parent_item_colon' => esc_html__('Parent Item:', 'rica'),
                        'all_items' => sprintf(esc_html__('All %s', 'rica'), $name),
                        'view_item' => esc_html__('View Item', 'rica'),
                        'add_new_item' => sprintf(esc_html__('Add New  %s', 'rica'), $name),
                        'add_new' => esc_html__('Add New', 'rica'),
                        'edit_item' => esc_html__('Edit Item', 'rica'),
                        'update_item' => esc_html__('Update Item', 'rica'),
                        'search_items' => esc_html__('Search Item', 'rica'),
                        'not_found' => esc_html__('Not found', 'rica'),
                        'not_found_in_trash' => esc_html__('Not found in Trash', 'rica'),
                    ),
                    'supports' => array('title', 'editor', 'excerpt', 'thumbnail'),
                    'public' => true,
                    'show_ui' => true,
                    '_builtin' => false,
                    'has_archive' => true,
                    'menu_icon' => 'dashicons-format-gallery',
                    'rewrite' => array('slug' => $slug, 'with_front' => true),
                )
            );
        }

        function register_taxonomies()
        {
            if (taxonomy_exists(GF_GALLERY_CATEGORY_TAXONOMY)) {
                return;
            }

            $post_type = GF_GALLERY_POST_TYPE;
            $taxonomy_slug = GF_GALLERY_CATEGORY_TAXONOMY;
            $taxonomy_name = 'Gallery Categories';

            $post_type_slug = get_option('gf-rica-' . $post_type . '-config');
            if (isset($post_type_slug) && is_array($post_type_slug) &&
                array_key_exists('taxonomy_slug', $post_type_slug) && $post_type_slug['taxonomy_slug'] != ''
            ) {
                $taxonomy_slug = $post_type_slug['taxonomy_slug'];
                $taxonomy_name = $post_type_slug['taxonomy_name'];
            }
            register_taxonomy(GF_GALLERY_CATEGORY_TAXONOMY, GF_GALLERY_POST_TYPE,
                array('hierarchical' => true,
                      'label' => $taxonomy_name,
                      'query_var' => true,
                      'rewrite' => array('slug' => $taxonomy_slug))
            );
        }

        function register_meta_boxes($meta_boxes)
        {

            $meta_boxes[] = array(
                'title' => esc_html__('Gallery Extra', 'rica'),
                'id' => 'rica-meta-box-food-extra',
                'pages' => array(GF_GALLERY_POST_TYPE),
                'fields' => array(
                    array(
                        'name' => esc_html__('Link to detail', 'rica'),
                        'id' => 'link',
                        'type' => 'text',
                    )
                )
            );
            return $meta_boxes;
        }
    }
    new GF_FrameWork_Gallery();
}