<?php
//==============================================================================
// SOCIAL PROFILE WIDGET
//==============================================================================
if (!class_exists('G5Plus_Widget_Social_Profile')) {
	class G5Plus_Widget_Social_Profile extends G5Plus_Widget
	{
		public function __construct()
		{
			$this->widget_cssclass = 'widget-social-profile';
			$this->widget_description = esc_html__("Social profile widget", 'rica');
			$this->widget_id = 'g5plus_social_profile';
			$this->widget_name = esc_html__('G5Plus - Social Profile', 'rica');
			$this->settings = array(
				'title' => array(
					'type'  => 'text',
					'std'   => '',
					'label' => esc_html__('Title', 'rica')
				),
				'icons' => array(
					'type'    => 'multi-select',
					'label'   => esc_html__('Select social profiles', 'rica'),
					'std'     => '',
					'options' => $this->get_profiles()
				),
				'style' => array(
					'type'    => 'select',
					'label'   => esc_html__('Style', 'rica'),
					'std'     => 'rectangle',
					'options' => array(
						'circle' => esc_html__('Circle', 'rica'),
						'rectangle'  => esc_html__('Rectangle', 'rica'),
						'border'  => esc_html__('Box Border', 'rica'),
					)
				)
			);
			parent::__construct();
		}

		function widget($args, $instance)
		{
			if ( $this->get_cached_widget( $args ) ) {
				return;
			}
			extract($args, EXTR_SKIP);
			$title = (!empty($instance['title'])) ? $instance['title'] : '';
			$icons = (!empty($instance['icons'])) ? $instance['icons'] : '';
			$style = (!empty($instance['style'])) ? $instance['style'] : 'classic';
			$social_profiles = array();
			if (function_exists('gf_get_social_profiles')) {
				$profiles = gf_get_social_profiles();
				foreach ($profiles as $value) {
					$social_profiles[$value['id']] = array(
						'title' => $value['title'],
						'icon' => $value['icon'],
						'type' => $value['type']
					);
				}
			}
			$arr_icons = array();
			if (!empty($icons)) {
				$arr_icons = explode(',', $icons);
			}
			ob_start();
			echo wp_kses_post($args['before_widget']);
			if ($title) {
				echo wp_kses_post($args['before_title'] . $title . $args['after_title']);
			}
			$class_wrap = array('social-profiles', esc_attr($style));
			if (count($arr_icons) > 0):
				?>
				<div class="<?php echo join(' ', $class_wrap) ?>">
					<?php foreach ($arr_icons as $key):
						if (!isset($social_profiles[$key])) {
							continue;
						}
						$title = $social_profiles[$key]['title'];
						$icon = $social_profiles[$key]['icon'];
						$link = '#';
						if (function_exists('gf_get_social_profiles')) {
							$link = g5plus_get_option($key,'#');
						}

						$link = empty($link) ? '#' : $link;
						?>
						<a title="<?php echo esc_attr($title) ?>"
						   href="<?php echo($social_profiles[$key]['type'] == 'email' ? esc_attr($link) : esc_url($link)); ?>"><i
								class="<?php echo esc_attr($icon); ?>"></i></a>
					<?php endforeach; ?>
					<div class="clearfix"></div>
				</div>
				<?php
			endif;
			echo wp_kses_post($args['after_widget']);

			$content =  ob_get_clean();
			echo wp_kses_post($content);
			$this->cache_widget( $args, $content );
		}

		private function get_profiles()
		{
			$ret = array();
			if (function_exists('gf_get_social_profiles')) {
				$profiles = gf_get_social_profiles();
				foreach ($profiles as $profile) {
					$ret[$profile['id']] = $profile['title'];
				}
			}
			return $ret;
		}
	}
}