<?php
/**
 * Created by PhpStorm.
 * User: phuongth
 * Date: 6/30/2016
 * Time: 3:08 PM
 */

if (!defined('ABSPATH')) die('-1');

if (!defined('GF_MENU_FOOD_CATEGORY_TAXONOMY'))
    define('GF_MENU_FOOD_CATEGORY_TAXONOMY', 'gf-menu-food-category');

if (!defined('GF_MENU_FOOD_POST_TYPE'))
    define('GF_MENU_FOOD_POST_TYPE', 'gf-menu-food');

if (!defined('GF_MENU_FOOD_DIR_PATH'))
    define('GF_MENU_FOOD_DIR_PATH', plugin_dir_path(__FILE__));

if (!class_exists('GF_FrameWork_Menu_Food')) {
    class GF_FrameWork_Menu_Food
    {
        function __construct(){
            add_action('init', array($this, 'register_taxonomies'), 5);
            add_action('init', array($this, 'register_post_types'), 6);
            add_filter('rwmb_meta_boxes', array($this, 'register_meta_boxes'));
            add_filter('g5plus_filter_page_layout', array($this, 'single_page_layout'));
            $this->ajax_action();
            if(is_admin()){
                $this->register_category_image();
            }
        }

        function register_post_types()
        {

            $post_type = GF_MENU_FOOD_POST_TYPE;

            if (post_type_exists($post_type)) {
                return;
            }

            $post_type_slug = get_option('gf-rica-' . $post_type . '-config');
            if (!isset($post_type_slug) || !is_array($post_type_slug)) {
                $slug = 'gf-menu-food';
                $name = $singular_name = 'Menu Food';
            } else {
                $slug = $post_type_slug['slug'];
                $name = $post_type_slug['name'];
                $singular_name = $post_type_slug['singular_name'];
            }

            register_post_type($post_type,
                array(
                    'label' => esc_html__('Menu Food', 'rica'),
                    'description' => esc_html__('Food Description', 'rica'),
                    'labels' => array(
                        'name' => $name,
                        'singular_name' => $singular_name,
                        'menu_name' => ucfirst($name),
                        'parent_item_colon' => esc_html__('Parent Item:', 'rica'),
                        'all_items' => sprintf(esc_html__('All %s', 'rica'), $name),
                        'view_item' => esc_html__('View Item', 'rica'),
                        'add_new_item' => sprintf(esc_html__('Add New  %s', 'rica'), $name),
                        'add_new' => esc_html__('Add New', 'rica'),
                        'edit_item' => esc_html__('Edit Item', 'rica'),
                        'update_item' => esc_html__('Update Item', 'rica'),
                        'search_items' => esc_html__('Search Item', 'rica'),
                        'not_found' => esc_html__('Not found', 'rica'),
                        'not_found_in_trash' => esc_html__('Not found in Trash', 'rica'),
                    ),
                    'supports' => array('title', 'editor', 'excerpt', 'thumbnail'),
                    'public' => true,
                    'show_ui' => true,
                    '_builtin' => false,
                    'has_archive' => true,
                    'menu_icon' => 'dashicons-cutlery',
                    'rewrite' => array('slug' => $slug, 'with_front' => true),
                )
            );
        }

        function register_taxonomies()
        {
            if (taxonomy_exists(GF_MENU_FOOD_CATEGORY_TAXONOMY)) {
                return;
            }

            $post_type = GF_MENU_FOOD_POST_TYPE;
            $taxonomy_slug = GF_MENU_FOOD_CATEGORY_TAXONOMY;
            $taxonomy_name = 'Food Categories';

            $post_type_slug = get_option('gf-rica-' . $post_type . '-config');
            if (isset($post_type_slug) && is_array($post_type_slug) &&
                array_key_exists('taxonomy_slug', $post_type_slug) && $post_type_slug['taxonomy_slug'] != ''
            ) {
                $taxonomy_slug = $post_type_slug['taxonomy_slug'];
                $taxonomy_name = $post_type_slug['taxonomy_name'];
            }
            register_taxonomy(GF_MENU_FOOD_CATEGORY_TAXONOMY, GF_MENU_FOOD_POST_TYPE,
                array('hierarchical' => true,
                      'label' => $taxonomy_name,
                      'query_var' => true,
                      'rewrite' => array('slug' => $taxonomy_slug))
            );
        }

        function register_meta_boxes($meta_boxes)
        {

            $meta_boxes[] = array(
                'title' => esc_html__('Food Extra', 'rica'),
                'id' => 'rica-meta-box-food-extra',
                'pages' => array(GF_MENU_FOOD_POST_TYPE),
                'fields' => array(
                    array(
                        'name' => esc_html__('Price', 'rica'),
                        'id' => 'food-price',
                        'type' => 'text',
                    ),
                    array(
                        'name' => esc_html__('Feature', 'rica'),
                        'id' => 'food-feature',
                        'type' => 'text'
                    ),
                    array(
                        'name' => esc_html__('Gallery', 'rica'),
                        'id' => 'food-gallery',
                        'type' => 'image_advanced',
                    )
                )
            );
            return $meta_boxes;
        }

        function register_category_image(){
            $config_cat_image = array(
                'id' => 'page_title_meta_box',          // meta box id, unique per meta box
                'title' => esc_html__('Image Icon','rica') ,          // meta box title
                'pages' => array(GF_MENU_FOOD_CATEGORY_TAXONOMY,'product_cat'),        // taxonomy name, accept categories, post_tag and custom taxonomies
                'context' => 'normal',            // where the meta box appear: normal (default), advanced, side; optional
                'fields' => array(),            // list of meta fields (can be added by field arrays)
                'local_images' => false,          // Use local or hosted images (meta box images for add/remove)
                'use_with_theme' => false          //change path if used with theme set to true, false for a plugin or anything else for a custom path(default false).
            );
            $cat_image_meta =  new Tax_Meta_Class($config_cat_image);
            $cat_image_meta->addImage(
                GF_METABOX_PREFIX.'category_image',
                array(
                    'name'=> esc_html__('Category Image','rica')
                )
            );
            $cat_image_meta->Finish();

        }

        function load_gallery_callback(){
            $post_id = $_REQUEST['post_id'];
            $post_type = $_REQUEST['post_type'];
            $galleries= array();
            if($post_type==='product'){
                if(function_exists('wc_get_product')){
                    $product = wc_get_product($post_id);
                    $meta_values = $product->get_gallery_image_ids();
                }
            }else{
                $meta_values = get_post_meta($post_id, 'food-gallery', false);
            }

            if(!is_array($meta_values) || count($meta_values)<=0){
                if (has_post_thumbnail( $post_id ) ){
                    $meta_values[] =  get_post_thumbnail_id( $post_id);
                }
            }

            if(is_array($meta_values) && count($meta_values)>0){
                $args_attachment = array(
                    'orderby' => 'post__in',
                    'post__in' => $meta_values,
                    'post_type' => 'attachment',
                    'posts_per_page' => '-1',
                    'post_status' => 'inherit');

                $attachments = new WP_Query($args_attachment);
                global $post;
                while ($attachments->have_posts()) : $attachments->the_post();
                    $galleries[] = array(
                        'subHtml' => $post->post_title,
                        'thumb' => $post->guid,
                        'src' => $post->guid,
                    );
                endwhile;
                wp_reset_postdata();
                echo json_encode($galleries);
            }
            wp_die();
        }

        function load_more_callback()
        {
            $show_category = $_REQUEST['show_category'];
            $data_source = $_REQUEST['data_source'];
            $category = $_REQUEST['category'];
            $menu_layout = $_REQUEST['menu_layout'];
            $columns = $_REQUEST['columns'];
            $post_per_page = $_REQUEST['post_per_page'];
            $total_items = $_REQUEST['total_items'];
            $current_page = $_REQUEST['current_page'];
            $image_position = $_REQUEST['image_position'];
            $post_type = isset($_REQUEST['post_type']) ? $_REQUEST['post_type'] : 'g5plus_menu_food';
            $short_code_name = $post_type==='product' ? 'g5plus_menu_food_product' : 'g5plus_menu_food';
            $short_code = sprintf('[%s data_source="%s" category="%s" menu_layout="%s" columns = "%s" post_per_page = "%s" total_items="%s"
              current_page = "%s" image_position="%s" show_category="%s"]', $short_code_name,
                $data_source, $category, $menu_layout, $columns, $post_per_page, $total_items, $current_page, $image_position, $show_category);
            if (class_exists('WPBMap')) {
                WPBMap::addAllMappedShortcodes();
            }
            echo do_shortcode($short_code);
            wp_die();
        }

        function ajax_action()
        {
            add_action("wp_ajax_nopriv_gf_menu_food_load_more", array($this, 'load_more_callback'));
            add_action("wp_ajax_gf_menu_food_load_more", array($this, 'load_more_callback'));

            add_action("wp_ajax_nopriv_gf_menu_food_load_gallery", array($this, 'load_gallery_callback'));
            add_action("wp_ajax_gf_menu_food_load_gallery", array($this, 'load_gallery_callback'));

        }

        function single_page_layout($page_layouts){
            if(is_singular(GF_MENU_FOOD_POST_TYPE)){
                $page_layouts = 'container';
            }
            return $page_layouts;
        }
    }
    new  GF_FrameWork_Menu_Food();

}