<?php
/**
 * COMMON FUNCTION FOR PLUGIN FRAMEWORK
 */

/**
 * GET Plugin template
 * *******************************************************
 */
function gf_get_template($slug, $args = array())
{
    if ($args && is_array($args)) {
        extract($args);
    }
    $located = GF_PLUGIN_DIR . $slug . '.php';
    if (!file_exists($located)) {
        _doing_it_wrong(__FUNCTION__, sprintf('<code>%s</code> does not exist.', $slug), '1.0');
        return;
    }
    include($located);
}

/**
 * GET Meta Box Value
 * *******************************************************
 */
if (!function_exists('gf_get_rwmb_meta')) {
    function gf_get_rwmb_meta($key, $args = array(), $post_id = null)
    {
        return rwmb_meta(GF_METABOX_PREFIX . $key, $args, $post_id);
    }
}

/**
 * GET Meta Box Image Value
 * *******************************************************
 */
if (!function_exists('gf_get_rwmb_meta_image')) {
    function gf_get_rwmb_meta_image($key, $post_id = null)
    {
        $metabox_id = gf_get_rwmb_meta($key, array(), $post_id);
        $metabox_value = gf_get_rwmb_meta($key, 'type=image_advanced', $post_id);
        if (($metabox_id === '') || ($metabox_id === false) || ($metabox_value === '') || ($metabox_value === false) || ($metabox_value === array())) {
            return false;
        }
        $image_url = '';
        if ($metabox_value !== array() && isset($metabox_value[$metabox_id]) && isset($metabox_value[$metabox_id]['full_url'])) {
            $image_url = $metabox_value[$metabox_id]['full_url'];
        }
        return $image_url;
    }
}

/**
 * GET theme option value
 * *******************************************************
 */
if (!function_exists('gf_get_option')) {
    function gf_get_option($key, $default = '')
    {
        return isset($GLOBALS[GF_OPTIONS_NAME][$key]) ? $GLOBALS[GF_OPTIONS_NAME][$key] : $default;
    }
}

/**
 * CONVERT hexa color to rgba color
 * *******************************************************
 */
if (!function_exists('gf_hex2rgba')) {
	function gf_hex2rgba($hex, $opacity) {
		if ($opacity > 1) {
			$opacity = $opacity / 100;
		}
		if (strtolower($hex) == 'transparent') {
			return 'transparent';
		}
		$hex = str_replace("#", "", $hex);

		if(strlen($hex) == 3) {
			$r = hexdec(substr($hex,0,1).substr($hex,0,1));
			$g = hexdec(substr($hex,1,1).substr($hex,1,1));
			$b = hexdec(substr($hex,2,1).substr($hex,2,1));
		} elseif(strlen($hex) == 6) {
			$r = hexdec(substr($hex,0,2));
			$g = hexdec(substr($hex,2,2));
			$b = hexdec(substr($hex,4,2));
		}
		else {
			$r = 0;
			$g = 0;
			$b = 0;
			$opacity = 0;
		}
		return sprintf('rgba(%s,%s,%s,%s)', $r, $g, $b, $opacity);
	}
}

/**
 * Load Preset Into Theme Options
 * *******************************************************
 */
if (!function_exists('gf_load_preset_into_theme_options')) {
	function &gf_load_preset_into_theme_options(&$options, $current_preset) {
		foreach ($options as $key => $value) {
			$field_type = isset(Redux::$fields[GF_OPTIONS_NAME])
			&& isset(Redux::$fields[GF_OPTIONS_NAME][$key])
			&& isset(Redux::$fields[GF_OPTIONS_NAME][$key]['type']) ? Redux::$fields[GF_OPTIONS_NAME][$key]['type'] : '';
			switch ($field_type) {
				case 'media':
					$meta_value = gf_get_rwmb_meta_image($key, $current_preset);
					if ($meta_value !== false) {
						$options[$key]['url'] = $meta_value;
					}
					break;
				case 'spacing':
					$meta_value = gf_get_rwmb_meta($key, array(), $current_preset);
					if ($meta_value !== '') {
						$options[$key]['padding-top'] = isset($meta_value['top']) && ($meta_value['top'] !== '') ? $meta_value['top'] . 'px' : '';
						$options[$key]['padding-bottom'] = isset($meta_value['bottom']) && ($meta_value['bottom'] !== '') ? $meta_value['bottom'] . 'px' : '';
					}
					break;
				case 'dimensions':
					$meta_value = gf_get_rwmb_meta($key, array(), $current_preset);
					if ($meta_value !== '') {
						$options[$key]['height'] = $meta_value;
					}
					break;
				case 'sorter':
					$meta_value = gf_get_rwmb_meta($key, array(), $current_preset);
					if ($meta_value !== '') {
						$enable_arr = isset($meta_value['enable']) ? $meta_value['enable'] : '';
						$enable_arr = explode('||', $enable_arr);

						$sorter_arr = array();
						if (isset($options[$key]['enabled']) && isset($options[$key]['disabled']) && is_array($options[$key]['enabled']) && is_array($options[$key]['enabled'])) {
							$sorter_arr = array_merge($options[$key]['enabled'], $options[$key]['disabled']);
						}
						$options[$key]['enabled'] = array();
						$options[$key]['disabled'] = array();
						foreach ($enable_arr as $sorter_key) {
							$sorter_value = isset($sorter_arr[$sorter_key]) ? $sorter_arr[$sorter_key] : '';
							$options[$key]['enabled'][$sorter_key] = $sorter_value;
						}
						foreach ($sorter_arr as $sorter_key => $sorter_value) {
							if (!in_array($sorter_key, $enable_arr)) {
								$options[$key]['disabled'][$sorter_key] = $sorter_value;
							}
						}
					}
					break;
				case 'label_value':
					$meta_value = gf_get_rwmb_meta($key, array(), $current_preset);
					if ($meta_value !== '') {
						$options[$key]['label'] = isset($meta_value['label']) ? $meta_value['label'] : '';
						$options[$key]['value'] = isset($meta_value['text']) ? $meta_value['text'] : '';
					}
					break;
				case 'background':
				case 'color_rgba':
				case 'typography':
					// NONE
					break;
				default:
					$meta_value = gf_get_rwmb_meta($key, array(), $current_preset);
					if ($meta_value !== '') {
						$options[$key] = $meta_value;
					}
					break;
			}

		}
		return $options;
	}
}

/**
 * Get Current Preset ID
 * *******************************************************
 */
if (!function_exists('gf_get_current_preset')) {
	function gf_get_current_preset() {
		global $post;

		$post_type = get_post_type($post);
		$preset_id = 0;
		$list_post_type = apply_filters('gf_post_type_preset', array());

		foreach ($list_post_type as $post_type_name => $post_type_value) {
			if (is_post_type_archive( $post_type_name ) || is_tax( $post_type_name . '_cat') || is_tax($post_type_name . '_tag') || (is_search() && ($post_type == $post_type_name))) {
				$page_preset = gf_get_option($post_type_name . '_preset');
				if ($page_preset) {
					$preset_id = $page_preset;
				}
			}
			/**
			 * Single Post Type
			 */
			elseif (is_singular($post_type_name)) {
				$page_preset = gf_get_option($post_type_name . '_single_preset');
				if ($page_preset) {
					$preset_id = $page_preset;
				}
			}
			if ($preset_id) {
				break;
			}
		}
		if ($preset_id) {}
		/**
		 * Product Page
		 */
		elseif (is_post_type_archive( 'product' ) || is_tax('product_cat') || is_tax('product_tag') || (is_search() && ($post_type == 'product'))) {
			$page_preset = gf_get_option('product_preset');
			$id = get_the_ID();
			if(  (function_exists('wc_get_page_id') && function_exists('is_shop') && is_shop() )
				|| ( function_exists('is_product_category') && is_product_category())
				|| ( function_exists('is_product_tag') && is_product_tag())
			){
				$id =  wc_get_page_id('shop');
			}
			$preset_id = gf_get_rwmb_meta('page_preset',array(),$id);
			if(!$preset_id=='' || $preset_id == 0){
				if ($page_preset) {
					$preset_id = $page_preset;
				}
			}

		}
		/**
		 * Single Product
		 */
		elseif (is_singular('product')) {
			$page_preset = gf_get_option('product_single_preset');
			if ($page_preset) {
				$preset_id = $page_preset;
			}
		}
		/**
		 * Event Page
		 */
		elseif (is_post_type_archive( 'tribe_events' ) || is_tax('tribe_events_cat') || is_tax('tribe_events_tag') || (is_search() && ($post_type == 'tribe_events'))) {
			$page_preset = gf_get_option('event_preset');
			if ($page_preset) {
				$preset_id = $page_preset;
			}
		}
		/**
		 * Single Event
		 */
		elseif (is_singular('tribe_events')) {
			$page_preset = gf_get_option('event_single_preset');
			if ($page_preset) {
				$preset_id = $page_preset;
			}
		}
		/**
		 * Blog
		 */
		elseif ((is_home() || is_category() || is_tag() || is_search() || is_archive()) && ($post_type == 'post')) {
			$page_preset = gf_get_option('blog_preset');

			$id = get_option( 'page_for_posts' );
			$preset_id = gf_get_rwmb_meta('page_preset',array(),$id);
			if(!$preset_id=='' || $preset_id == 0){
				if ($page_preset) {
					$preset_id = $page_preset;
				}
			}
		}
		/**
		 * Blog Single
		 */
		elseif (is_singular('post')) {
			$page_preset = gf_get_option('blog_single_preset');
			if ($page_preset) {
				$preset_id = $page_preset;
			}
		}
		/**
		 * 404 Page
		 */
		elseif (is_404()) {
			$page_preset = gf_get_option('page_404_preset');
			if ($page_preset) {
				$preset_id = $page_preset;
			}
		}


		/**
		 * Single Page
		 */
		if (is_singular()) {
			/**
			 * Get Preset
			 */
			$page_preset = gf_get_rwmb_meta('page_preset');
			if ($page_preset) {
				$preset_id = $page_preset;
			}

			if (is_singular('gf_preset')) {
				$preset_id = get_the_ID();
			}
		}
		return $preset_id;
	}
}

/**
 * Get Preset Dir
 * *******************************************************
 */
if (!function_exists('gf_get_preset_dir')) {
	function gf_get_preset_dir() {
		return trailingslashit(get_template_directory()) . 'assets/preset/';
	}
}

/**
 * Get Preset Url
 * *******************************************************
 */
if (!function_exists('gf_get_preset_url')) {
	function gf_get_preset_url() {
		return trailingslashit(get_template_directory_uri()) . 'assets/preset/';
	}
}

/**
 * Enqueue Preset Style
 * @preset_type: style, rtl, tta
 * *******************************************************
 */
if (!function_exists('gf_enqueue_preset_style')) {
	function gf_enqueue_preset_style($preset_id, $preset_type) {
		$filename = $preset_id . '.' . $preset_type . '.min.css';
		if (!file_exists(gf_get_preset_dir() . $filename)) {
			gf_generate_less($preset_id);
			if (!file_exists(gf_get_preset_dir() . $filename)) {
				return false;
			}
		}
		wp_enqueue_style(GF_PLUGIN_PREFIX . '_preset_' . $preset_type, gf_get_preset_url() . $filename);
		return true;
	}
}

/**
 * Get Fonts Awesome Array
 * *******************************************************
 */
if (!function_exists('gf_get_font_awesome')) {
	function &gf_get_font_awesome() {
		if (function_exists('g5plus_get_font_awesome')) {
			return g5plus_get_font_awesome();
		}
		$fonts = array();
		return $fonts;
	}
}

/**
 * Get Theme Font Icon
 * *******************************************************
 */
if (!function_exists('gf_get_theme_font')) {
	function &gf_get_theme_font() {
		if (function_exists('g5plus_get_theme_font')) {
			return g5plus_get_theme_font();
		}
		$fonts = array();
		return $fonts;
	}
}
/**
 * Get Theme Custom User
 * *******************************************************
 */
if(!function_exists('gf_get_customer_meta_fields')){
	function gf_get_customer_meta_fields() {
		$show_fields = apply_filters('gf_get_customer_meta_fields', array(

			'job-author' =>array(
				'title' => esc_html__('Job','rica'),
				'fields' => array(
					'job' => array(
						'label' => esc_html__('Your Job','rica'),
						'description' => esc_html__('Your Job... ','rica'),
						'type' => 'text',
					)
				)

			),

		) );
		return $show_fields;
	}
}
if(!function_exists('gf_add_customer_meta_fields')){
	function gf_add_customer_meta_fields( $user ) {

		$show_fields = gf_get_customer_meta_fields();

		foreach ( $show_fields as $fieldset ) :
			?>
			<h3><?php echo wp_kses_post($fieldset['title']); ?></h3>
			<table class="form-table">
				<?php
				foreach ( $fieldset['fields'] as $key => $field ) :
					?>
					<tr>
						<th><label for="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $field['label'] ); ?></label></th>
						<td>
							<?php if ( ! empty( $field['type'] ) && 'select' == $field['type'] ) : ?>
								<select name="<?php echo esc_attr( $key ); ?>" id="<?php echo esc_attr( $key ); ?>" class="<?php echo ( ! empty( $field['class'] ) ? $field['class'] : '' ); ?>" style="width: 25em;">
									<?php
									$selected = esc_attr( get_user_meta( $user->ID, $key, true ) );
									foreach ( $field['options'] as $option_key => $option_value ) : ?>
										<option value="<?php echo esc_attr( $option_key ); ?>" <?php selected( $selected, $option_key, true ); ?>><?php echo esc_attr( $option_value ); ?></option>
									<?php endforeach; ?>
								</select>
							<?php else : ?>
								<input type="text" name="<?php echo esc_attr( $key ); ?>" id="<?php echo esc_attr( $key ); ?>" value="<?php echo esc_attr( get_user_meta( $user->ID, $key, true ) ); ?>" class="<?php echo ( ! empty( $field['class'] ) ? $field['class'] : 'regular-text' ); ?>" />
							<?php endif; ?>
							<br/>
							<span class="description"><?php echo wp_kses_post( $field['description'] ); ?></span>
						</td>
					</tr>
					<?php
				endforeach;
				?>
			</table>
			<?php
		endforeach;
	}
}
if(!function_exists('gf_save_customer_meta_fields')){
	function gf_save_customer_meta_fields( $user_id ) {
		$save_fields = gf_get_customer_meta_fields();

		foreach ( $save_fields as $fieldset ) {
			foreach ( $fieldset['fields'] as $key => $field ) {
				if ( isset( $_POST[ $key ] )  ) {
					update_user_meta( $user_id, $key, sanitize_text_field( $_POST[ $key ] ) );
				}
			}
		}
	}
}

/**
 * Social Icons
 * *******************************************************
 */
if (!function_exists('gf_get_social_icon_share')) {
	function gf_get_social_icon_share() {
		get_template_part('templates/social-share');
	}
    add_action('woocommerce_share','gf_get_social_icon_share',10);
}