<?php
/**
 * THEME OPTIONS CONFIG FILE
 * *******************************************************
 */
if (!class_exists('Redux')) {
    return;
}

if (!class_exists('GF_Options_Config')) {
    class GF_Options_Config
    {
        public function __construct()
        {
            $this->initSettings();
        }

        public function initSettings()
        {
            // Set the default arguments
            $this->setArguments();
            // Create the sections and fields
            $this->setSections();
        }

        /**
         * HELPER
         * *******************************************************
         */
        private function get_section_start($id, $title)
        {
            return array(
                'id'     => $id . '_start',
                'type'   => 'section',
                'title'  => $title,
                'indent' => true
            );
        }

        private function get_section_end($id)
        {
            return array(
                'id'     => $id . '_end',
                'type'   => 'section',
                'indent' => false
            );
        }

        private function get_page_layout($id, $required = array(), $default = 'container')
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Layout', 'rica'),
                'subtitle' => esc_html__('Select Page Layout', 'rica'),
                'desc'     => '',
                'options'  => gf_get_page_layout(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_sidebar_layout($id, $required = array(), $default = 'right')
        {
            return array(
                'id'       => $id,
                'type'     => 'image_select',
                'title'    => esc_html__('Sidebar Layout', 'rica'),
                'subtitle' => esc_html__('Set Sidebar Layout', 'rica'),
                'desc'     => '',
                'options'  => gf_get_sidebar_layout(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_sidebar_width($id, $required = array(), $default = 'small')
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Width', 'rica'),
                'subtitle' => esc_html__('Set Sidebar width', 'rica'),
                'desc'     => '',
                'options'  => gf_get_sidebar_width(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_sidebar_mobile_enable($id, $required = array(), $default = 1)
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Sidebar Mobile', 'rica'),
                'subtitle' => esc_html__('Turn Off this option if you want to disable sidebar on mobile', 'rica'),
                'desc'     => '',
                'options'  => gf_get_toggle(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_sidebar_mobile_canvas( $id, $required = array(), $default = 1 ) {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__( 'Canvas Sidebar Mobile', 'rica' ),
                'subtitle' => esc_html__( 'Turn Off this option if you want to disable canvas sidebar on mobile', 'rica' ),
                'desc'     => '',
                'options'  => gf_get_toggle(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_sidebar($id, $required = array(), $default = 'main-sidebar')
        {
            return array(
                'id'       => $id,
                'type'     => 'select',
                'title'    => esc_html__('Sidebar', 'rica'),
                'subtitle' => '',
                'data'     => 'sidebars',
                'desc'     => '',
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_content_padding($id, $required = array(), $default = array('padding-top' => '70px', 'padding-bottom' => '70px', 'units' => 'px'))
        {
            return array(
                'id'             => $id,
                'type'           => 'spacing',
                'mode'           => 'padding',
                'units'          => 'px',
                'units_extended' => 'false',
                'title'          => esc_html__('Content Padding', 'rica'),
                'subtitle'       => esc_html__('Set content top/bottom padding.', 'rica'),
                'desc'           => esc_html__('Allow values (0,5,10,15....100)', 'rica'),
                'left'           => false,
                'right'          => false,
                'default'        => $default,
                'required'       => $required,
            );
        }

        private function get_content_padding_mobile($id, $required = array(), $default = array('padding-top' => '', 'padding-bottom' => '', 'units' => 'px'))
        {
            return array(
                'id'             => $id,
                'type'           => 'spacing',
                'mode'           => 'padding',
                'units'          => 'px',
                'units_extended' => 'false',
                'title'          => esc_html__('Content Padding Mobile', 'rica'),
                'subtitle'       => esc_html__('Set content top/bottom padding mobile.', 'rica'),
                'desc'           => esc_html__('Allow values (0,5,10,15....100)', 'rica'),
                'left'           => false,
                'right'          => false,
                'default'        => $default,
                'required'       => $required,
            );
        }

        private function get_page_title_enable($id, $required = array(), $default = 1)
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Page Title Enable', 'rica'),
                'subtitle' => esc_html__('Enable/Disable Page Title', 'rica'),
                'desc'     => '',
                'options'  => gf_get_toggle(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_page_title_layout($id, $required = array(), $default = 'normal')
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Page Title Layout', 'rica'),
                'desc'     => '',
                'options'  => gf_get_page_title_layout(),
                'default'  => $default,
                'required' => $required
            );
        }

        private function get_page_sub_title($id, $required = array())
        {
            return array(
                'id'       => $id,
                'type'     => 'text',
                'title'    => esc_html__('Page Sub Title', 'rica'),
                'subtitle' => '',
                'desc'     => '',
                'default'  => '',
                'required' => $required,
            );
        }

        private function get_page_title_padding($id, $required = array(), $default = array('padding-top' => '', 'padding-bottom' => '', 'units' => 'px'))
        {
            return array(
                'id'             => $id,
                'type'           => 'spacing',
                'mode'           => 'padding',
                'units'          => 'px',
                'units_extended' => 'false',
                'title'          => esc_html__('Padding', 'rica'),
                'subtitle'       => esc_html__('Set page title top/bottom padding.', 'rica'),
                'desc'           => '',
                'left'           => false,
                'right'          => false,
                'default'        => $default,
                'required'       => $required,
            );
        }


        private function get_page_title_background_image($id, $required = array(), $default = array())
        {
            return array(
                'id'       => $id,
                'type'     => 'media',
                'url'      => true,
                'title'    => esc_html__('Background Image', 'rica'),
                'subtitle' => esc_html__('Upload page title background.', 'rica'),
                'desc'     => '',
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_page_title_parallax($id, $required = array(), $default = 1)
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Page Title Parallax', 'rica'),
                'subtitle' => esc_html__('Enable Page Title Parallax', 'rica'),
                'desc'     => '',
                'options'  => gf_get_toggle(),
                'default'  => $default,
                'required' => $required,
            );
        }

        private function get_breadcrumb_enable($id, $required = array(), $default = 1)
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Breadcrumbs Enable', 'rica'),
                'subtitle' => esc_html__('Enable/Disable Breadcrumbs In Pages Title', 'rica'),
                'desc'     => '',
                'options'  => gf_get_toggle(),
                'default'  => $default,
                'required' => $required
            );
        }

        private function get_theme_color_enable($id, $required = array(), $default = 0)
        {
            return array(
                'id'       => $id,
                'type'     => 'button_set',
                'title'    => esc_html__('Customize Color', 'rica'),
                'subtitle' => esc_html__('Select "Customize" if you want to change default theme color', 'rica'),
                'desc'     => '',
                'options'  => gf_get_toggle_color(),
                'default'  => $default,
                'required' => $required,
            );
        }

        /**
         * END: HELPER
         * *******************************************************
         */

        /**
         * Set Arguments
         */
        public function setArguments()
        {
            // This is your option name where all the Redux data is stored.
            $opt_name = GF_OPTIONS_NAME;

            $theme = wp_get_theme(); // For use with some settings. Not necessary.

            $args = array(
                // TYPICAL -> Change these values as you need/desire
                'opt_name'             => $opt_name,
                // This is where your data is stored in the database and also becomes your global variable name.
                'display_name'         => $theme->get('Name'),
                // Name that appears at the top of your panel
                'display_version'      => $theme->get('Version'),
                // Version that appears at the top of your panel
                'menu_type'            => 'menu',
                //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
                'allow_sub_menu'       => false,
                // Show the sections below the admin menu item or not
                'menu_title'           => __('Theme Options', 'rica'),
                'page_title'           => __('Theme Options', 'rica'),
                // You will need to generate a Google API key to use this feature.
                // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
                'google_api_key'       => '',
                // Set it you want google fonts to update weekly. A google_api_key value is required.
                'google_update_weekly' => false,
                // Must be defined to add google fonts to the typography module
                'async_typography'     => true,
                // Use a asynchronous font on the front end or font string
                //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
                'admin_bar'            => true,
                // Show the panel pages on the admin bar
                'admin_bar_icon'       => 'dashicons-portfolio',
                // Choose an icon for the admin bar menu
                'admin_bar_priority'   => 50,
                // Choose an priority for the admin bar menu
                'global_variable'      => '',
                // Set a different name for your global variable other than the opt_name
                'dev_mode'             => false,
                // Show the time the page took to load, etc
                'update_notice'        => true,
                // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
                'customizer'           => true,
                // Enable basic customizer support
                //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
                //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

                // OPTIONAL -> Give you extra features
                'page_priority'        => null,
                // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
                'page_parent'          => 'themes.php',
                // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
                'page_permissions'     => 'manage_options',
                // Permissions needed to access the options panel.
                'menu_icon'            => '',
                // Specify a custom URL to an icon
                'last_tab'             => '',
                // Force your panel to always open to a specific tab (by id)
                'page_icon'            => 'icon-themes',
                // Icon displayed in the admin panel next to your menu_title
                'page_slug'            => '_options',
                // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
                'save_defaults'        => true,
                // On load save the defaults to DB before user clicks save or not
                'default_show'         => false,
                // If true, shows the default value next to each field that is not the default value.
                'default_mark'         => '',
                // What to print by the field's title if the value shown is default. Suggested: *
                'show_import_export'   => true,
                // Shows the Import/Export panel when not used as a field.

                // CAREFUL -> These options are for advanced use only
                'transient_time'       => 60 * MINUTE_IN_SECONDS,
                'output'               => true,
                // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
                'output_tag'           => true,
                // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
                // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

                // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
                'database'             => '',
                // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
                'use_cdn'              => true,
                // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

                // HINTS
                'hints'                => array(
                    'icon'          => 'el el-question-sign',
                    'icon_position' => 'right',
                    'icon_color'    => 'lightgray',
                    'icon_size'     => 'normal',
                    'tip_style'     => array(
                        'color'   => 'red',
                        'shadow'  => true,
                        'rounded' => false,
                        'style'   => '',
                    ),
                    'tip_position'  => array(
                        'my' => 'top left',
                        'at' => 'bottom right',
                    ),
                    'tip_effect'    => array(
                        'show' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'mouseover',
                        ),
                        'hide' => array(
                            'effect'   => 'slide',
                            'duration' => '500',
                            'event'    => 'click mouseleave',
                        ),
                    ),
                )
            );

            Redux::setArgs($opt_name, $args);

            /*
			 * ---> END ARGUMENTS
			 */
        }

        /**
         * Set Section
         */
        public function setSections()
        {
            $opt_name = GF_OPTIONS_NAME;

            /**
             * Set Fonts
             * *******************************************************
             */
            $fonts = array(
                "Arial, Helvetica, sans-serif"                         => "Arial, Helvetica, sans-serif",
                "'Arial Black', Gadget, sans-serif"                    => "'Arial Black', Gadget, sans-serif",
                "'Bookman Old Style', serif"                           => "'Bookman Old Style', serif",
                "'Comic Sans MS', cursive"                             => "'Comic Sans MS', cursive",
                "Courier, monospace"                                   => "Courier, monospace",
                "Garamond, serif"                                      => "Garamond, serif",
                "Georgia, serif"                                       => "Georgia, serif",
                "Impact, Charcoal, sans-serif"                         => "Impact, Charcoal, sans-serif",
                "'Lucida Console', Monaco, monospace"                  => "'Lucida Console', Monaco, monospace",
                "'Lucida Sans Unicode', 'Lucida Grande', sans-serif"   => "'Lucida Sans Unicode', 'Lucida Grande', sans-serif",
                "'MS Sans Serif', Geneva, sans-serif"                  => "'MS Sans Serif', Geneva, sans-serif",
                "'MS Serif', 'New York', sans-serif"                   => "'MS Serif', 'New York', sans-serif",
                "'Palatino Linotype', 'Book Antiqua', Palatino, serif" => "'Palatino Linotype', 'Book Antiqua', Palatino, serif",
                "Tahoma,Geneva, sans-serif"                            => "Tahoma, Geneva, sans-serif",
                "'Times New Roman', Times,serif"                       => "'Times New Roman', Times, serif",
                "'Trebuchet MS', Helvetica, sans-serif"                => "'Trebuchet MS', Helvetica, sans-serif",
                "Verdana, Geneva, sans-serif"                          => "Verdana, Geneva, sans-serif",
            );

            $_framework_options = get_option(GF_OPTIONS_NAME);
            if (is_array($_framework_options)) {
                for ($i = 1; $i <= 2; $i++) {
                    if (array_key_exists('custom_font_' . $i . '_name', $_framework_options)) {
                        $custom_font = $_framework_options['custom_font_' . $i . '_name'];
                    }
                    if (array_key_exists('custom_font_' . $i . '_ttf', $_framework_options)) {
                        $ttf = $_framework_options['custom_font_' . $i . '_ttf'];
                    }
                    if (array_key_exists('custom_font_' . $i . '_eot', $_framework_options)) {
                        $eot = $_framework_options['custom_font_' . $i . '_eot'];
                    }
                    if (array_key_exists('custom_font_' . $i . '_woff', $_framework_options)) {
                        $woff = $_framework_options['custom_font_' . $i . '_woff'];
                    }
                    if (isset($custom_font) && isset($ttf) && isset($eot) && isset($woff) && $custom_font != '') {
                        $fonts[$custom_font] = 'Custom - ' . $custom_font;
                    }
                }
            }

	        /**
	         * Post Type Preset
	         */
	        $post_type_preset = apply_filters('gf_post_type_preset', array());
	        $post_type_preset_list = array();
	        foreach ($post_type_preset as $post_type_name => $post_type_value) {
		        $post_type_preset_list[] = array(
			        'id' => 'divide_preset_setting_' . $post_type_name,
			        'type' => 'divide',
		        );
		        $post_type_preset_list[] = array(
			        'id' => $post_type_name . '_preset',
			        'type' => 'select',
			        'data' => 'posts',
			        'title' => $post_type_value . esc_html__(' Preset','rica'),
			        'placeholder' => esc_html__('Select Preset...', 'rica'),
			        'default' => '',
			        'args' => array(
				        'post_type' => 'gf_preset'
			        )
		        );
		        $post_type_preset_list[] = array(
			        'id' => $post_type_name . '_single_preset',
			        'type' => 'select',
			        'data' => 'posts',
			        'title' => $post_type_value . esc_html__(' Single Preset', 'rica'),
			        'placeholder' => esc_html__('Select Preset...', 'rica'),
			        'default' => '',
			        'args' => array(
				        'post_type' => 'gf_preset'
			        )
		        );
	        }

            /**
             * General Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('General Setting', 'rica'),
                'id'     => 'general',
                'desc'   => esc_html__('These are general setting!', 'rica'),
                'icon'   => 'el el-home',
                'fields' => array(
                    array(
                        'id'       => 'smooth_scroll',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Smooth Scroll', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Smooth Scroll', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),

                    array(
                        'id'       => 'custom_scroll',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Custom Scroll', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Custom Scroll', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),

                    array(
                        'id'       => 'custom_scroll_width',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom Scroll Width', 'rica'),
                        'subtitle' => esc_html__('This must be numeric (no px) or empty.', 'rica'),
                        'validate' => 'numeric',
                        'default'  => '10',
                        'required' => array('custom_scroll', '=', 1),
                    ),

                    array(
                        'id'       => 'custom_scroll_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Custom Scroll Color', 'rica'),
                        'subtitle' => esc_html__('Set Custom Scroll Color', 'rica'),
                        'default'  => '#19394B',
                        'validate' => 'color',
                        'required' => array('custom_scroll', '=', 1),
                    ),

                    array(
                        'id'       => 'custom_scroll_thumb_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Custom Scroll Thumb Color', 'rica'),
                        'subtitle' => esc_html__('Set Custom Scroll Thumb Color', 'rica'),
                        'default'  => '#e8aa00',
                        'validate' => 'color',
                        'required' => array('custom_scroll', '=', 1),
                    ),

                    array(
                        'id'       => 'back_to_top',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Back To Top', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Back to top button', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'enable_rtl_mode',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Enable RTL mode', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable RTL mode', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),

                    array(
                        'id'       => 'social_meta_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Enable Social Meta Tags', 'rica'),
                        'subtitle' => esc_html__('Enable the social meta head tag output.', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),

                    array(
                        'id'       => 'twitter_author_username',
                        'type'     => 'text',
                        'title'    => esc_html__('Twitter Publisher Username', 'rica'),
                        'subtitle' => esc_html__('Enter your twitter username here, to be used for the Twitter Card date. Ensure that you do not include the @ symbol.', 'rica'),
                        'desc'     => '',
                        'default'  => "",
                        'required' => array('enable_social_meta', '=', array('1')),
                    ),
                    array(
                        'id'       => 'googleplus_author',
                        'type'     => 'text',
                        'title'    => esc_html__('Google+ Username', 'rica'),
                        'subtitle' => esc_html__('Enter your Google+ username here, to be used for the authorship meta.', 'rica'),
                        'desc'     => '',
                        'default'  => "",
                        'required' => array('enable_social_meta', '=', array('1')),
                    ),


                    array(
                        'id'   => 'general_divide_2',
                        'type' => 'divide'
                    ),

                    array(
                        'id'       => 'shopping_cart_button',
                        'type'     => 'checkbox',
                        'title'    => esc_html__('Shopping Mini Cart Button', 'rica'),
                        'subtitle' => esc_html__('Select shopping mini cart button', 'rica'),
                        'options'  => array(
                            'view-cart' => esc_html__('View Cart', 'rica'),
                            'checkout'  => esc_html__('Checkout', 'rica'),
                        ),
                        'default'  => array(
                            'view-cart' => '1',
                            'checkout'  => '1',
                        ),
                    ),
                    array(
                        'id'       => 'search_popup_type',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Search Popup Type', 'rica'),
                        'subtitle' => esc_html__('Select search popup type.', 'rica'),
                        'desc'     => '',
                        'options'  => array('standard' => esc_html__('Standard', 'rica'), 'ajax' => esc_html__('Ajax Search', 'rica')),
                        'default'  => 'standard'
                    ),
                    array(
                        'id'       => 'search_popup_post_type',
                        'type'     => 'checkbox',
                        'title'    => esc_html__('Post type for Ajax Search', 'rica'),
                        'subtitle' => esc_html__('Select post type for ajax search', 'rica'),
                        'options'  => array(
                            'post'      => 'Post',
                            'page'      => 'Page',
                            'product'   => 'Product',
                        ),
                        'default'  => array(
                            'post'      => '1',
                            'page'      => '0',
                            'product'   => '1',
                        ),
                        'required' => array('search_popup_type', '=', 'ajax'),
                    ),

                    array(
                        'id'       => 'search_popup_result_amount',
                        'type'     => 'text',
                        'title'    => esc_html__('Amount Of Search Result', 'rica'),
                        'subtitle' => esc_html__('This must be numeric (no px) or empty (default: 8).', 'rica'),
                        'desc'     => esc_html__('Set mount of Search Result', 'rica'),
                        'validate' => 'numeric',
                        'default'  => '',
                        'required' => array('search_popup_type', '=', 'ajax'),
                    ),

                    array(
                        'id'   => 'general_divide_3',
                        'type' => 'divide'
                    ),
                    array(
                        'id'       => 'menu_transition',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Menu transition', 'rica'),
                        'subtitle' => esc_html__('Select menu transition', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'none'                  => esc_html__('None', 'rica'),
                            'x-animate-slide-up'    => esc_html__('Slide Up', 'rica'),
                            'x-animate-slide-down'  => esc_html__('Slide Down', 'rica'),
                            'x-animate-slide-left'  => esc_html__('Slide Left', 'rica'),
                            'x-animate-slide-right' => esc_html__('Slide Right', 'rica'),
                            'x-animate-sign-flip'   => esc_html__('Sign Flip', 'rica'),
                        ),
                        'default'  => 'x-animate-sign-flip'
                    ),
                )
            ));

            /**
             * Maintenance Mode Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'      => esc_html__('Maintenance Mode', 'rica'),
                'desc'       => '',
                'subsection' => true,
                'icon'       => 'el el-wrench',
                'fields'     => array(
                    array(
                        'id'       => 'enable_maintenance',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Enable Maintenance', 'rica'),
                        'subtitle' => esc_html__('Enable the themes maintenance mode.', 'rica'),
                        'desc'     => '',
                        'options'  => array('2' => 'On (Custom Page)', '1' => 'On (Standard)', '0' => 'Off',),
                        'default'  => '0'
                    ),
                    array(
                        'id'       => 'maintenance_mode_page',
                        'type'     => 'select',
                        'data'     => 'pages',
                        'required' => array('enable_maintenance', '=', '2'),
                        'title'    => esc_html__('Custom Maintenance Mode Page', 'rica'),
                        'subtitle' => esc_html__('Select the page that is your maintenace page, if you would like to show a custom page instead of the standard WordPress message. You should use the Holding Page template for this page.', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                        'args'     => array()
                    ),
                ),
            ));

            /**
             * Performance Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'      => esc_html__('Performance', 'rica'),
                'desc'       => '',
                'icon'       => 'el el-fire',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'       => 'enable_minifile_js',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Enable Mini File JS', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Mini File JS', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),
                    array(
                        'id'       => 'enable_minifile_css',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Enable Mini File CSS', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Mini File CSS', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),
                )
            ));

            /**
             * Page Transition Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'      => esc_html__('Page Transition', 'rica'),
                'desc'       => '',
                'icon'       => 'el el-dashboard',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'       => 'page_transition',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Page Transition', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Page Transition', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),

                    array(
                        'id'       => 'loading_animation',
                        'type'     => 'select',
                        'title'    => esc_html__('Loading Animation', 'rica'),
                        'subtitle' => esc_html__('Choose type of preload animation', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'none'          => esc_html__('No animation', 'rica'),
                            'cube'          => esc_html__('Cube', 'rica'),
                            'double-bounce' => esc_html__('Double bounce', 'rica'),
                            'wave'          => esc_html__('Wave', 'rica'),
                            'pulse'         => esc_html__('Pulse', 'rica'),
                            'chasing-dots'  => esc_html__('Chasing dots', 'rica'),
                            'three-bounce'  => esc_html__('Three bounce', 'rica'),
                            'circle'        => esc_html__('Circle', 'rica'),
                            'fading-circle' => esc_html__('Fading circle', 'rica'),
                            'folding-cube'  => esc_html__('Folding cube', 'rica'),
                        ),
                        'default'  => 'none'
                    ),

                    array(
                        'id'       => 'loading_logo',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Logo Loading', 'rica'),
                        'subtitle' => esc_html__('Upload logo loading.', 'rica'),
                        'desc'     => '',
                        'required' => array('loading_animation', 'not_empty_and', array('none')),
                    ),

                    array(
                        'id'       => 'loading_animation_bg_color',
                        'type'     => 'color_rgba',
                        'title'    => esc_html__('Loading Background Color', 'rica'),
                        'subtitle' => esc_html__('Set loading background color.', 'rica'),
                        'default'  => array(
                            'color' => '#ffffff',
                            'alpha' => 1
                        ),
                        'output'   => array('background-color' => '.site-loading'),
                        'validate' => 'colorrgba',
                        'required' => array('loading_animation', 'not_empty_and', array('none')),
                    ),

                    array(
                        'id'       => 'spinner_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Spinner color', 'rica'),
                        'subtitle' => esc_html__('Pick a spinner color', 'rica'),
                        'default'  => '',
                        'validate' => 'color',
                        'output'   => array('background-color' => '.sk-spinner-pulse,.sk-rotating-plane,.sk-double-bounce .sk-child,.sk-wave .sk-rect,.sk-chasing-dots .sk-child,.sk-three-bounce .sk-child,.sk-circle .sk-child:before,.sk-fading-circle .sk-circle:before,.sk-folding-cube .sk-cube:before'),
                        'required' => array('loading_animation', 'not_empty_and', array('none')),
                    ),
                )
            ));

            /**
             * Custom Favicon
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'      => esc_html__('Custom Favicon', 'rica'),
                'desc'       => '',
                'icon'       => 'el el-eye-open',
                'subsection' => true,
                'fields'     => array(
                    array(
                        'id'       => 'custom_favicon',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Custom favicon', 'rica'),
                        'subtitle' => esc_html__('Upload a 16px x 16px Png/Gif/ico image that will represent your website favicon', 'rica'),
                        'desc'     => ''
                    ),
                    array(
                        'id'       => 'custom_ios_title',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom iOS Bookmark Title', 'rica'),
                        'subtitle' => esc_html__('Enter a custom title for your site for when it is added as an iOS bookmark.', 'rica'),
                        'desc'     => '',
                        'default'  => ''
                    ),
                    array(
                        'id'       => 'custom_ios_icon57',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Custom iOS 57x57', 'rica'),
                        'subtitle' => esc_html__('Upload a 57px x 57px Png image that will be your website bookmark on non-retina iOS devices.', 'rica'),
                        'desc'     => ''
                    ),
                    array(
                        'id'       => 'custom_ios_icon72',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Custom iOS 72x72', 'rica'),
                        'subtitle' => esc_html__('Upload a 72px x 72px Png image that will be your website bookmark on non-retina iOS devices.', 'rica'),
                        'desc'     => ''
                    ),
                    array(
                        'id'       => 'custom_ios_icon114',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Custom iOS 114x114', 'rica'),
                        'subtitle' => esc_html__('Upload a 114px x 114px Png image that will be your website bookmark on retina iOS devices.', 'rica'),
                        'desc'     => ''
                    ),
                    array(
                        'id'       => 'custom_ios_icon144',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Custom iOS 144x144', 'rica'),
                        'subtitle' => esc_html__('Upload a 144px x 144px Png image that will be your website bookmark on retina iOS devices.', 'rica'),
                        'desc'     => ''
                    ),
                )
            ));

            /**
             * 404 Setting Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'      => esc_html__('404 Setting', 'rica'),
                'desc'       => '',
                'subsection' => true,
                'icon'       => 'el el-error',
                'fields'     => array(
                    array(
                        'id'      => '404_apply_setting',
                        'type'    => 'select',
                        'title'   => esc_html__('404 Page Apply Setting', 'rica'),
                        'data'    => 'page',
                        'default' => '',
                    ),
                    array(
                        'id'       => '404_title',
                        'type'     => 'text',
                        'title'    => esc_html__('Title', 'rica'),
                        'default'  => 'Page not found!',
                    ),
                    array(
                        'id'       => '404_sub_title',
                        'type'     => 'text',
                        'title'    => esc_html__('Sub Title', 'rica'),
                        'default'  => "Sorry, We couldn't find the page you're looking for.",
                    ),
                    array(
                        'id'       => '404_return_description',
                        'type'     => 'text',
                        'title'    => esc_html__('Return Description', 'rica'),
                        'default'  => "Try returning to the",
                    ),
                    array(
                        'id'       => '404_return_text_link',
                        'type'     => 'text',
                        'title'    => esc_html__('Return Text Link', 'rica'),
                        'default'  => "homepage",
                    ),
                    array(
                        'id'       => '404_return_link',
                        'type'     => 'text',
                        'title'    => esc_html__('Return Link', 'rica'),
                        'description' => esc_html__('If link null, link default is home page', 'rica'),
                        'default'  => "",
                    ),
                    array(
                        'id'      => 'image_404',
                        'type'    => 'media',
                        'url'     => true,
                        'title'   => esc_html__('Background image', 'rica'),
                        'desc'    => '',
                        'default' => array(
                            'url' => trailingslashit(get_template_directory_uri()) . 'assets/images/404-image.png'
                        )
                    ),
                    array(
                        'id'      => 'background_image_404',
                        'type'    => 'media',
                        'url'     => true,
                        'title'   => esc_html__('Background image', 'rica'),
                        'desc'    => '',
                        'default' => array(
                            'url' => trailingslashit(get_template_directory_uri()) . 'assets/images/bg-404-page.jpg'
                        )
                    ),
                )
            ));

            /**
             * Layout Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Layout Options', 'rica'),
                'icon'   => 'el el-website',
                'fields' => array(
                    // General
                    array(
                        'id'       => 'layout_style',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Layout Style', 'rica'),
                        'subtitle' => esc_html__('Select the layout style', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_layout_style(),
                        'default'  => 'wide'
                    ),
                    array(
                        'id'       => 'body_background_mode',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Body Background Mode', 'rica'),
                        'subtitle' => esc_html__('Chose Background Mode', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'background' => esc_html__('Background', 'rica'),
                            'pattern'    => esc_html__('Pattern', 'rica')
                        ),
                        'default'  => 'background',
                    ),
                    array(
                        'id'       => 'body_background',
                        'type'     => 'background',
                        'output'   => array('body'),
                        'title'    => esc_html__('Body Background', 'rica'),
                        'subtitle' => esc_html__('Body background (Apply for Boxed layout style).', 'rica'),
                        'default'  => array(
                            'background-color'      => '',
                            'background-repeat'     => 'no-repeat',
                            'background-position'   => 'center center',
                            'background-attachment' => 'fixed',
                            'background-size'       => 'cover'
                        ),
                        'required' => array(
                            array('body_background_mode', '=', array('background'))
                        ),
                    ),
                    array(
                        'id'       => 'body_background_pattern',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Background Pattern', 'rica'),
                        'subtitle' => esc_html__('Body background pattern(Apply for Boxed layout style)', 'rica'),
                        'desc'     => '',
                        'height'   => '40px',
                        'options'  => array(
                            'pattern-1.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-1.png'),
                            'pattern-2.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-2.png'),
                            'pattern-3.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-3.png'),
                            'pattern-4.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-4.png'),
                            'pattern-5.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-5.png'),
                            'pattern-6.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-6.png'),
                            'pattern-7.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-7.png'),
                            'pattern-8.png' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/pattern-8.png'),
                        ),
                        'default'  => 'pattern-1.png',
                        'required' => array(
                            array('body_background_mode', '=', array('pattern'))
                        ),
                    ),
                    $this->get_page_layout('layout'),
                    $this->get_sidebar_layout('sidebar_layout'),
                    $this->get_sidebar('sidebar', array('sidebar_layout', '=', array('left', 'right'))),
                    $this->get_sidebar_width('sidebar_width', array('sidebar_layout', '=', array('left', 'right'))),
                    $this->get_sidebar_mobile_enable('sidebar_mobile_enable', array('sidebar_layout', '=', array('left', 'right'))),
                    $this->get_sidebar_mobile_canvas( 'sidebar_mobile_canvas', array('sidebar_mobile_enable','=',1)),
                    array(
                        'id'      => 'widget_layout',
                        'type'    => 'select',
                        'title'   => esc_html__('Widget Layout', 'rica'),
                        'options' => gf_get_widget_layout(),
                        'default' => 'widget-classic'
                    ),
                    $this->get_content_padding('content_padding'),
                    $this->get_content_padding_mobile('content_padding_mobile'),
                )
            ));

            /**
             * Page Title Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Page Title', 'rica'),
                'icon'   => 'el el-asterisk',
                'fields' => array(
                    $this->get_page_title_enable('page_title_enable'),
                    $this->get_page_title_padding('page_title_padding', array('page_title_enable', '=', 1), array('padding-top' => '250', 'padding-bottom' => '230', 'units' => 'px')),
                    $this->get_page_title_background_image('page_title_bg_image', array('page_title_enable', '=', 1), array('url'=> GF_PLUGIN_URL . 'assets/images/theme-options/page-title.jpg' )),
                    $this->get_page_title_parallax('page_title_parallax', array(array('page_title_enable', '=', 1), array('page_title_bg_image', '!=', '')), 0),
                    $this->get_breadcrumb_enable('breadcrumbs_enable', array('page_title_enable', '=', 1)),
                )
            ));

            /**
             * Blog Setting Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Blog Setting', 'rica'),
                'icon'   => 'el el-blogger',
                'fields' => array(
                    array(
                        'id'     => 'blog_start',
                        'type'   => 'section',
                        'title'  => esc_html__('Blog Options', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'post_layout',
                        'type'     => 'select',
                        'title'    => esc_html__('Post Layout', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'select2' => array('allowClear' => false),
                        'options'  => gf_get_post_layout(),
                        'default'  => 'list',
                    ),
                    array(
                        'id'       => 'post_column',
                        'type'     => 'select',
                        'title'    => esc_html__('Post Columns', 'rica'),
                        'subtitle' => '',
                        'options'  => gf_get_post_columns(),
                        'desc'     => '',
                        'default'  => 2,
                        'required' => array('post_layout', '=', array('masonry','grid-image')),
                    ),
                    array(
                        'id'       => 'post_paging',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Post Paging', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_paging_style(),
                        'default'  => 'navigation'
                    ),
                    array(
                        'id'       => 'post_no_image_display',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Display Post No Image', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => array(
                            '1' => esc_html__('On','rica'),
                            '0' => esc_html__('Off','rica'),
                        ),
                        'default' => '0',
                    ),

                    array(
                        'id'     => 'single_blog_start',
                        'type'   => 'section',
                        'title'  => esc_html__('Single Blog Options', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'single_title_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Title', 'rica'),
                        'subtitle' => esc_html__('Turn Off this option if you want to hide title on single blog', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),
                    array(
                        'id'       => 'single_tag_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Tags', 'rica'),
                        'subtitle' => esc_html__('Turn Off this option if you want to hide tags on single blog', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'single_share_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Share', 'rica'),
                        'subtitle' => esc_html__('Turn Off this option if you want to hide share on single blog', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'single_navigation_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Navigation', 'rica'),
                        'subtitle' => esc_html__('Turn Off this option if you want to hide navigation on single blog', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),
                    array(
                        'id'       => 'single_author_info_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Author Info', 'rica'),
                        'subtitle' => esc_html__('Turn Off this option if you want to hide author info area on single blog', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'single_related_post_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Related Post', 'rica'),
                        'subtitle' => esc_html__('Turn Off this option if you want to hide related post area on single blog', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'single_related_post_total',
                        'type'     => 'text',
                        'title'    => esc_html__('Related Post Total', 'rica'),
                        'subtitle' => esc_html__('Total record of Related Post.', 'rica'),
                        'validate' => 'number',
                        'default'  => 6,
                        'required' => array('single_related_post_enable', '=', 1),
                    ),

                    array(
                        'id'       => 'single_related_post_column',
                        'type'     => 'select',
                        'title'    => esc_html__('Related Post Columns', 'rica'),
                        'default'  => 3,
                        'options'  => array(3 => '3', 4 => '4'),
                        'select2'  => array('allowClear' => false),
                        'required' => array('single_related_post_enable', '=', 1),
                    ),

                    array(
                        'id'       => 'single_related_post_condition',
                        'type'     => 'checkbox',
                        'title'    => esc_html__('Related Post Condition', 'rica'),
                        'options'  => array(
                            'category' => esc_html__('Same Category', 'rica'),
                            'tag'      => esc_html__('Same Tag', 'rica'),
                        ),
                        'default'  => array(
                            'category' => '1',
                            'tag'      => '1',
                        ),
                        'required' => array('single_related_post_enable', '=', 1),
                    ),
                )
            ));

            /**
             * Logo Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Logo Setting', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-leaf',
                'fields' => array(
                    array(
                        'id'     => 'section-logo-desktop',
                        'type'   => 'section',
                        'title'  => esc_html__('Logo Desktop', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'logo',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Logo', 'rica'),
                        'subtitle' => esc_html__('Upload your logo here.', 'rica'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => trailingslashit(get_template_directory_uri()) . 'assets/images/logo.png'
                        )
                    ),
                    array(
                        'id'       => 'logo_retina',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Logo Retina', 'rica'),
                        'subtitle' => esc_html__('Upload your logo retina here.', 'rica'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => ''
                        )
                    ),
                    array(
                        'id'       => 'sticky_logo',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Sticky Logo', 'rica'),
                        'subtitle' => esc_html__('Upload a sticky version of your logo here', 'rica'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => trailingslashit(get_template_directory_uri()) . 'assets/images/logo.png'
                        )
                    ),
                    array(
                        'id'       => 'sticky_logo_retina',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Sticky Logo Retina', 'rica'),
                        'subtitle' => esc_html__('Upload a sticky version of your logo retina here', 'rica'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => ''
                        )
                    ),
                    array(
                        'id'      => 'logo_max_height',
                        'type'    => 'dimensions',
                        'title'   => esc_html__('Logo Max Height', 'rica'),
                        'desc'    => esc_html__('You can set a max height for the logo here', 'rica'),
                        'units'   => false,
                        'width'   => false,
                        'default' => array(
                            'height' => ''
                        )
                    ),
                    array(
                        'id'             => 'logo_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Logo Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '',
                            'padding-bottom' => '',
                            'units'          => 'px',
                        )
                    ),

                    array(
                        'id'     => 'section-logo-mobile',
                        'type'   => 'section',
                        'title'  => esc_html__('Logo Mobile', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'mobile_logo',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Mobile Logo', 'rica'),
                        'subtitle' => esc_html__('Upload your logo here.', 'rica'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => trailingslashit(get_template_directory_uri()) . 'assets/images/logo.png'
                        )
                    ),
                    array(
                        'id'       => 'mobile_logo_retina',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Mobile Logo Retina', 'rica'),
                        'subtitle' => esc_html__('Upload your logo retina here.', 'rica'),
                        'desc'     => '',
                        'default'  => array(
                            'url' => ''
                        )
                    ),
                    array(
                        'id'      => 'mobile_logo_max_height',
                        'type'    => 'dimensions',
                        'title'   => esc_html__('Mobile Logo Max Height', 'rica'),
                        'desc'    => esc_html__('You can set a max height for the logo mobile here', 'rica'),
                        'units'   => false,
                        'width'   => false,
                        'default' => array(
                            'height' => ''
                        )
                    ),
                    array(
                        'id'             => 'mobile_logo_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Logo Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '',
                            'padding-bottom' => '',
                            'units'          => 'px',
                        )
                    ),

                )
            ));

            /**
             * Top Drawer Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Top Drawer', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-photo',
                'fields' => array(
                    array(
                        'id'       => 'top_drawer_type',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Top Drawer Type', 'rica'),
                        'subtitle' => esc_html__('Set top drawer type.', 'rica'),
                        'desc'     => '',
                        'options'  => array('none' => 'Disable', 'show' => 'Always Show', 'toggle' => 'Toggle'),
                        'default'  => 'none'
                    ),
                    array(
                        'id'       => 'top_drawer_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Drawer Sidebar', 'rica'),
                        'subtitle' => "Choose the default top drawer sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_drawer_sidebar',
                        'required' => array('top_drawer_type', '=', array('show', 'toggle')),
                    ),

                    array(
                        'id'       => 'top_drawer_wrapper_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Top Drawer Wrapper Layout', 'rica'),
                        'subtitle' => esc_html__('Select top drawer wrapper layout', 'rica'),
                        'desc'     => '',
                        'options'  => array('full' => 'Full Width', 'container' => 'Container', 'container-fluid' => 'Container Fluid'),
                        'default'  => 'container',
                        'required' => array('top_drawer_type', '=', array('show', 'toggle')),
                    ),

                    array(
                        'id'       => 'top_drawer_hide_mobile',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show/Hide Top Drawer on mobile', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => 'On', '0' => 'Off'),
                        'default'  => '1',
                        'required' => array('top_drawer_type', '=', array('show', 'toggle')),
                    ),
                    array(
                        'id'             => 'top_drawer_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Logo Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default top drawer top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '',
                            'padding-bottom' => '',
                            'units'          => 'px',
                        ),
                        'required'       => array('top_drawer_type', '=', array('show', 'toggle')),
                    ),
                )
            ));

            /**
             * Top Bar Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Top Bar', 'rica'),
                'desc'   => esc_html__('Setting for Top Bar', 'rica'),
                'icon'   => 'el el-minus',
                'fields' => array(
                    array(
                        'id'     => 'section-top-bar-desktop',
                        'type'   => 'section',
                        'title'  => esc_html__('Desktop Settings', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'top_bar_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show/Hide Top Bar', 'rica'),
                        'subtitle' => esc_html__('Show Hide Top Bar.', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => esc_html__('Show', 'rica'), '0' => esc_html__('Hide', 'rica')),
                        'default'  => '0',
                    ),
                    array(
                        'id'       => 'top_bar_wrapper_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Top Bar Wrapper Layout', 'rica'),
                        'subtitle' => esc_html__('Select top bar wrapper layout', 'rica'),
                        'desc'     => '',
                        'options'  => array('container' => 'Container', 'container-fluid' => 'Container Fluid'),
                        'default'  => 'container',
                        'required' => array('top_bar_enable', '=', '1'),
                    ),
                    array(
                        'id'       => 'top_bar_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Top bar Layout', 'rica'),
                        'subtitle' => esc_html__('Select the top bar column layout.', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'top-bar-1' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-1.jpg'),
                            'top-bar-2' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-2.jpg'),
                            'top-bar-3' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-3.jpg'),
                            'top-bar-4' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-4.jpg'),
                        ),
                        'default'  => 'top-bar-1',
                        'required' => array('top_bar_enable', '=', '1'),
                    ),

                    array(
                        'id'       => 'top_bar_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Left Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the default top left sidebar', 'rica'),
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_left',
                        'required' => array('top_bar_enable', '=', '1'),
                    ),
                    array(
                        'id'       => 'top_bar_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Right Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the default top right sidebar', 'rica'),
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_right',
                        'required' => array('top_bar_enable', '=', '1'),
                    ),
                    array(
                        'id'       => 'top_bar_border',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Top bar border', 'rica'),
                        'options'  => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default'  => 'none',
                        'required' => array('top_bar_enable', '=', '1'),
                    ),
                    array(
                        'id'             => 'top_bar_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Top Bar Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default top bar top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '11',
                            'padding-bottom' => '11',
                            'units'          => 'px',
                        ),
                        'required'       => array('top_bar_enable', '=', '1'),
                    ),

                    //--------------------------------------------------------------
                    array(
                        'id'     => 'section-top-bar-mobile',
                        'type'   => 'section',
                        'title'  => esc_html__('Mobile Settings', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'top_bar_mobile_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show/Hide Top Bar', 'rica'),
                        'subtitle' => esc_html__('Show Hide Top Bar.', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => esc_html__('Show', 'rica'), '0' => esc_html__('Hide', 'rica')),
                        'default'  => '0',
                    ),
                    array(
                        'id'       => 'top_bar_mobile_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Top bar Layout', 'rica'),
                        'subtitle' => esc_html__('Select the top bar column layout.', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'top-bar-1' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-1.jpg'),
                            'top-bar-2' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-2.jpg'),
                            'top-bar-3' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-3.jpg'),
                            'top-bar-4' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/top-bar-layout-4.jpg'),
                        ),
                        'default'  => 'top-bar-1',
                        'required' => array('top_bar_mobile_enable', '=', '1'),
                    ),

                    array(
                        'id'       => 'top_bar_mobile_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Left Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the default top left sidebar', 'rica'),
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_left',
                        'required' => array('top_bar_mobile_enable', '=', '1'),
                    ),
                    array(
                        'id'       => 'top_bar_mobile_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Top Right Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the default top right sidebar', 'rica'),
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'top_bar_right',
                        'required' => array('top_bar_mobile_enable', '=', '1'),
                    ),
                    array(
                        'id'       => 'top_bar_mobile_border',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Top bar mobile border', 'rica'),
                        'options'  => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default'  => 'container-border',
                        'required' => array('top_bar_mobile_enable', '=', '1'),
                    ),
                    array(
                        'id'             => 'top_bar_mobile_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Top Bar Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default top bar top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '',
                            'padding-bottom' => '',
                            'units'          => 'px',
                        ),
                        'required'       => array('top_bar_mobile_enable', '=', '1'),
                    ),
                )
            ));

            /**
             * Header Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Header', 'rica'),
                'desc'   => esc_html__('Setting for Theme Header', 'rica'),
                'icon'   => 'el el-credit-card',
                'fields' => array(
                    array(
                        'id'       => 'header_responsive_breakpoint',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Header responsive breakpoint', 'rica'),
                        'subtitle' => esc_html__('Set header responsive breakpoint', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            '991' => esc_html__('Medium Devices: < 992px', 'rica'),
                            '767' => esc_html__('Tablet Portrait: < 768px', 'rica'),
                        ),
                        'default'  => '991'
                    ),
                    array(
                        'id'     => 'section-header-desktop',
                        'type'   => 'section',
                        'title'  => esc_html__('Desktop Settings', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'header_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Header Layout', 'rica'),
                        'subtitle' => esc_html__('Select a header layout option from the examples.', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'header-1'  => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-1.png'),
                            'header-2'  => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-2.png'),
                            'header-3'  => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-3.png'),
                            'header-4'  => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-4.png'),
                            'header-5'  => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-5.png'),
                            'header-6'  => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-6.png'),
                        ),
                        'default'  => 'header-1'
                    ),
                    array(
                        'id'      => 'header_container_layout',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Header container layout', 'rica'),
                        'options' => array(
                            'container'      => esc_html__('Container', 'rica'),
                            'container-fluid' => esc_html__('Container Fluid', 'rica'),
                        ),
                        'default' => 'container'
                    ),
                    array(
                        'id'       => 'header_float',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Header Float', 'rica'),
                        'subtitle' => esc_html__('Enable/Disable Header Float.', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => '0',
                    ),
                    array(
                        'id'       => 'header_sticky',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show/Hide Header Sticky', 'rica'),
                        'subtitle' => esc_html__('Show Hide header Sticky.', 'rica'),
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => '1'
                    ),
                    array(
                        'id'       => 'header_border_bottom',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Header border bottom', 'rica'),
                        'subtitle' => esc_html__('Set header border bottom', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default'  => 'none',
                        'required' => array('header_layout', '=', array('header-1', 'header-5')),
                    ),
                    array(
                        'id'       => 'header_above_border_bottom',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Header above border bottom', 'rica'),
                        'subtitle' => esc_html__('Set header above border bottom', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default'  => 'none',
                        'required' => array('header_layout', '=', array('header-5')),
                    ),
                    array(
                        'id'             => 'header_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Header Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default header top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '20',
                            'padding-bottom' => '20',
                            'units'          => 'px',
                        ),
                        'required' => array('header_layout', '!=', 'header-s'),
                    ),
                    array(
                        'id'      => 'navigation_height',
                        'type'    => 'dimensions',
                        'title'   => esc_html__('Navigation height', 'rica'),
                        'desc'    => esc_html__('Set header navigation height (px). Do not include unit. Empty to default', 'rica'),
                        'units'   => false,
                        'width'   => false,
                        'default' => array(
                            'height' => ''
                        ),
                        'required' => array('header_layout', '=', array('header-5','header-6')),
                    ),
                    array(
                        'id'      => 'navigation_spacing',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation Spacing (px)', 'rica'),
                        'default' => '50',
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 100,
                    ),

                    //---------------------------------------------------------------
                    array(
                        'id'     => 'section-header-mobile',
                        'type'   => 'section',
                        'title'  => esc_html__('Mobile Settings', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'mobile_header_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Header Layout', 'rica'),
                        'subtitle' => esc_html__('Select header mobile layout', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'header-mobile-1' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-mobile-layout-1.png'),
                            'header-mobile-2' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-mobile-layout-2.png'),
                            'header-mobile-3' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-mobile-layout-3.png'),
                            'header-mobile-4' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/header-mobile-layout-4.png'),
                        ),
                        'default'  => 'header-mobile-1'
                    ),
                    array(
                        'id'       => 'mobile_header_menu_drop',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Menu Drop Type', 'rica'),
                        'subtitle' => esc_html__('Set menu drop type for mobile header', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'menu-drop-fly'      => esc_html__('Fly Menu', 'rica'),
                            'menu-drop-dropdown' => esc_html__('Dropdown Menu', 'rica'),
                        ),
                        'default'  => 'menu-drop-fly'
                    ),
                    array(
                        'id'       => 'mobile_header_stick',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Stick Mobile Header', 'rica'),
                        'subtitle' => esc_html__('Enable Stick Mobile Header.', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => esc_html__('On', 'rica'), '0' => esc_html__('Off', 'rica')),
                        'default'  => '0'
                    ),
                    array(
                        'id'       => 'mobile_header_search_box',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Search Box', 'rica'),
                        'subtitle' => esc_html__('Enable Search Box.', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => esc_html__('Show', 'rica'), '0' => esc_html__('Hide', 'rica')),
                        'default'  => '1'
                    ),
                    array(
                        'id'       => 'mobile_header_shopping_cart',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Shopping Cart', 'rica'),
                        'subtitle' => esc_html__('Enable Shopping Cart', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => esc_html__('Show', 'rica'), '0' => esc_html__('Hide', 'rica')),
                        'default'  => '1'
                    ),
                    array(
                        'id'      => 'mobile_header_border_bottom',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Mobile header border bottom', 'rica'),
                        'options' => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default' => 'none',
                    ),
                )
            ));

            /**
             * Header Customize Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Header Customize', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-credit-card',
                'fields' => array(
                    array(
                        'id'       => 'section-header-customize-left',
                        'type'     => 'section',
                        'title'    => esc_html__('Header Customize Left', 'rica'),
                        'indent'   => true,
                        'required' => array('header_layout', '=', array('header-5')),
                    ),
                    array(
                        'id'      => 'header_customize_left',
                        'type'    => 'sorter',
                        'title'   => 'Header customize left',
                        'desc'    => 'Organize how you want the layout to appear on the header left',
                        'options' => array(
                            'enabled'  => array(
                                'shopping-cart' => esc_html__('Shopping Cart', 'rica'),
                            ),
                            'disabled' => array(
                                'search'      => esc_html__('Search', 'rica'),
                                'sidebar'     => esc_html__('Sidebar', 'rica'),
                                'custom-text' => esc_html__('Custom Text', 'rica'),
                            )
                        )
                    ),
                    array(
                        'id'      => 'header_customize_left_search',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Search Type', 'rica'),
                        'default' => 'button',
                        'options' => array(
                            'button'           => esc_html__('Button', 'rica'),
                            'box'              => esc_html__('Box', 'rica'),
                        ),
                    ),
                    array(
                        'id'       => 'header_customize_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the sidebar for header right customize', 'rica'),
                        'data'     => 'sidebars',
                        'default'  => '',
                    ),
                    array(
                        'id'       => 'header_customize_left_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'monokai',
                        'title'    => esc_html__('Custom Text Content', 'rica'),
                        'subtitle' => esc_html__('Add Content for Custom Text', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                    array(
                        'id'      => 'header_customize_left_spacing',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation Item Spacing (px)', 'rica'),
                        'default' => '40',
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 100,
                    ),
                    array(
                        'id'       => 'header_customize_left_css_class',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom CSS Class', 'rica'),
                        'subtitle' => esc_html__('Add custom css class', 'rica'),
                        'default'  => '',
                    ),
                    array(
                        'id'       => 'section-header-customize-right',
                        'type'     => 'section',
                        'title'    => esc_html__('Header Customize Right', 'rica'),
                        'indent'   => true,
                        'required' => array('header_layout', '=', array('header-5','header-6')),
                    ),
                    array(
                        'id'      => 'header_customize_right',
                        'type'    => 'sorter',
                        'title'   => 'Header customize right',
                        'desc'    => 'Organize how you want the layout to appear on the header right',
                        'options' => array(
                            'enabled'  => array(),
                            'disabled' => array(
                                'search'        => esc_html__('Search', 'rica'),
                                'shopping-cart' => esc_html__('Shopping Cart', 'rica'),
                                'sidebar'       => esc_html__('Sidebar', 'rica'),
                                'custom-text'   => esc_html__('Custom Text', 'rica'),
                            )
                        )
                    ),
                    array(
                        'id'      => 'header_customize_right_search',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Search Type', 'rica'),
                        'default' => 'button',
                        'options' => array(
                            'button'           => esc_html__('Button', 'rica'),
                            'box'              => esc_html__('Box', 'rica'),
                        ),
                    ),
                    array(
                        'id'       => 'header_customize_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the sidebar for header right customize', 'rica'),
                        'data'     => 'sidebars',
                        'default'  => '',
                    ),
                    array(
                        'id'       => 'header_customize_right_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'monokai',
                        'title'    => esc_html__('Custom Text Content', 'rica'),
                        'subtitle' => esc_html__('Add Content for Custom Text', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                    array(
                        'id'      => 'header_customize_right_spacing',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation Item Spacing (px)', 'rica'),
                        'default' => '40',
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 100,
                    ),
                    array(
                        'id'       => 'header_customize_right_css_class',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom CSS Class', 'rica'),
                        'subtitle' => esc_html__('Add custom css class', 'rica'),
                        'default'  => '',
                    ),
                    array(
                        'id'     => 'section-header-customize-nav',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Customize Navigation', 'rica'),
                        'indent' => true,
                    ),
                    array(
                        'id'      => 'header_customize_nav',
                        'type'    => 'sorter',
                        'title'   => 'Header customize navigation',
                        'desc'    => 'Organize how you want the layout to appear on the header navigation',
                        'options' => array(
                            'enabled'  => array(),
                            'disabled' => array(
                                'search'        => esc_html__('Search', 'rica'),
                                'shopping-cart' => esc_html__('Shopping Cart', 'rica'),
                                'sidebar'       => esc_html__('Sidebar', 'rica'),
                                'custom-text'   => esc_html__('Custom Text', 'rica'),
                            )
                        )
                    ),
                    array(
                        'id'      => 'header_customize_nav_search',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Search Type', 'rica'),
                        'default' => 'button',
                        'options' => array(
                            'button'           => esc_html__('Button', 'rica'),
                            'box'              => esc_html__('Box', 'rica'),
                        ),
                    ),
                    array(
                        'id'       => 'header_customize_nav_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar', 'rica'),
                        'subtitle' => esc_html__('Choose the sidebar for header customize navigation', 'rica'),
                        'data'     => 'sidebars',
                        'default'  => '',
                    ),
                    array(
                        'id'       => 'header_customize_nav_text',
                        'type'     => 'ace_editor',
                        'mode'     => 'html',
                        'theme'    => 'monokai',
                        'title'    => esc_html__('Custom Text Content', 'rica'),
                        'subtitle' => esc_html__('Add Content for Custom Text', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 5, 'maxLines' => 60),
                    ),
                    array(
                        'id'      => 'header_customize_nav_spacing',
                        'type'    => 'slider',
                        'title'   => esc_html__('Navigation Item Spacing (px)', 'rica'),
                        'default' => '40',
                        'min'     => 0,
                        'step'    => 1,
                        'max'     => 100,
                    ),
                    array(
                        'id'       => 'header_customize_nav_css_class',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom CSS Class', 'rica'),
                        'subtitle' => esc_html__('Add custom css class', 'rica'),
                        'default'  => '',
                    ),
                )
            ));

            /**
             * Footer Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Footer', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-website',
                'fields' => array(
                    array(
                        'id'       => 'footer_container_layout',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Footer Container Layout', 'rica'),
                        'subtitle' => esc_html__('Select Footer Container Layout', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'full'            => esc_html__('Full Width', 'rica'),
                            'container-fluid' => esc_html__('Container Fluid', 'rica'),
                            'container'       => esc_html__('Container', 'rica')
                        ),
                        'default'  => 'container'
                    ),
                    array(
                        'id'       => 'footer_parallax',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Footer Parallax', 'rica'),
                        'subtitle' => esc_html__('Enable Footer Parallax', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => 'Enable', '0' => 'Disable'),
                        'default'  => '0'
                    ),
	                array(
		                'id'       => 'set_footer_custom',
		                'type'     => 'select',
		                'title'    => esc_html__('Custom Footer', 'rica'),
		                'data'     => 'posts',
		                'default' => '',
		                'args' => array(
			                'post_type' => 'gf_footer'
		                ),
	                ),

                    array(
                        'id'     => 'section-footer-general-settings',
                        'type'   => 'section',
                        'title'  => esc_html__('General Settings', 'rica'),
                        'indent' => true,
                        'required' => array('set_footer_custom', '=', ''),
                    ),

                    array(
                        'id'       => 'footer_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Layout', 'rica'),
                        'subtitle' => esc_html__('Select the footer column layout.', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'footer-1' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-1.jpg'),
                            'footer-2' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-2.jpg'),
                            'footer-3' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-3.jpg'),
                            'footer-4' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-4.jpg'),
                            'footer-5' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-5.jpg'),
                            'footer-6' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-6.jpg'),
                            'footer-7' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-7.jpg'),
                            'footer-8' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-8.jpg'),
                            'footer-9' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/footer-layout-9.jpg'),
                        ),
                        'default'  => 'footer-1'
                    ),

                    array(
                        'id'       => 'footer_sidebar_1',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar 1', 'rica'),
                        'subtitle' => "Choose the default footer sidebar 1",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'footer-1',
                    ),

                    array(
                        'id'       => 'footer_sidebar_2',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar 2', 'rica'),
                        'subtitle' => "Choose the default footer sidebar 2",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'footer-2',
                        'required' => array('footer_layout', '=', array('footer-1', 'footer-2', 'footer-3', 'footer-4', 'footer-5', 'footer-6', 'footer-7', 'footer-8'))
                    ),

                    array(
                        'id'       => 'footer_sidebar_3',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar 3', 'rica'),
                        'subtitle' => "Choose the default footer sidebar 3",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'footer-3',
                        'required' => array('footer_layout', '=', array('footer-1', 'footer-2', 'footer-3', 'footer-5', 'footer-8'))
                    ),

                    array(
                        'id'       => 'footer_sidebar_4',
                        'type'     => 'select',
                        'title'    => esc_html__('Sidebar 4', 'rica'),
                        'subtitle' => "Choose the default footer sidebar 4",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'footer-4',
                        'required' => array('footer_layout', '=', array('footer-1'))
                    ),
                    array(
                        'id'       => 'footer_bg_image',
                        'type'     => 'media',
                        'url'      => true,
                        'title'    => esc_html__('Background image', 'rica'),
                        'subtitle' => esc_html__('Upload footer background image here', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                    ),

                    array(
                        'id'       => 'collapse_footer',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Collapse footer on mobile device', 'rica'),
                        'subtitle' => esc_html__('Enable collapse footer', 'rica'),
                        'desc'     => '',
                        'options'  => array('1' => 'On', '0' => 'Off'),
                        'default'  => '0'
                    ),
                    array(
                        'id'             => 'footer_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Footer Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px)', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default footer top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '60px',
                            'padding-bottom' => '60px',
                            'units'          => 'px',
                        )
                    ),
                    array(
                        'id'      => 'footer_border_top',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Footer border top', 'rica'),
                        'options' => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default' => 'none',
                    ),
                    array(
                        'id'       => 'footer_css_class',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom CSS Class', 'rica'),
                        'subtitle' => esc_html__('Add custom css class', 'rica'),
                        'default'  => '',
                    ),

                    //--------------------------------------------------------------------------------
                    array(
                        'id'     => 'section-footer-bottom-settings',
                        'type'   => 'section',
                        'title'  => esc_html__('Bottom Bar Settings', 'rica'),
                        'indent' => true,
                        'required' => array('set_footer_custom', '=', ''),
                    ),
                    array(
                        'id'       => 'bottom_bar_layout',
                        'type'     => 'image_select',
                        'title'    => esc_html__('Bottom bar Layout', 'rica'),
                        'subtitle' => esc_html__('Select the bottom bar column layout.', 'rica'),
                        'desc'     => '',
                        'options'  => array(
                            'bottom-bar-1' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/bottom-bar-layout-1.jpg'),
                            'bottom-bar-2' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/bottom-bar-layout-2.jpg'),
                            'bottom-bar-3' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/bottom-bar-layout-3.jpg'),
                            'bottom-bar-4' => array('title' => '', 'img' => GF_PLUGIN_URL . 'assets/images/theme-options/bottom-bar-layout-4.jpg'),
                        ),
                        'default'  => 'bottom-bar-1',
                    ),

                    array(
                        'id'       => 'bottom_bar_left_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Bottom Left Sidebar', 'rica'),
                        'subtitle' => "Choose the default bottom left sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'bottom_bar_left',
                    ),
                    array(
                        'id'       => 'bottom_bar_right_sidebar',
                        'type'     => 'select',
                        'title'    => esc_html__('Bottom Right Sidebar', 'rica'),
                        'subtitle' => "Choose the default bottom right sidebar",
                        'data'     => 'sidebars',
                        'desc'     => '',
                        'default'  => 'bottom_bar_right',
                    ),
                    array(
                        'id'             => 'bottom_bar_padding',
                        'type'           => 'spacing',
                        'mode'           => 'padding',
                        'units'          => 'px',
                        'units_extended' => 'false',
                        'title'          => esc_html__('Bottom Bar Top/Bottom Padding', 'rica'),
                        'subtitle'       => esc_html__('This must be numeric (no px). Leave balnk for default.', 'rica'),
                        'desc'           => esc_html__('If you would like to override the default bottom bar top/bottom padding, then you can do so here.', 'rica'),
                        'left'           => false,
                        'right'          => false,
                        'default'        => array(
                            'padding-top'    => '25px',
                            'padding-bottom' => '25px',
                            'units'          => 'px',
                        ),
                    ),
                    array(
                        'id'      => 'bottom_bar_border_top',
                        'type'    => 'button_set',
                        'title'   => esc_html__('Bottom bar border top', 'rica'),
                        'options' => array(
                            'none'             => esc_html__('None', 'rica'),
                            'full-border'      => esc_html__('Full Border', 'rica'),
                            'container-border' => esc_html__('Container Border', 'rica'),
                        ),
                        'default' => 'none',
                    ),
                    array(
                        'id'       => 'bottom_bar_css_class',
                        'type'     => 'text',
                        'title'    => esc_html__('Custom CSS Class', 'rica'),
                        'subtitle' => esc_html__('Add custom css class', 'rica'),
                        'default'  => '',
                    ),
                )
            ));

            /**
             * Theme Color Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Theme Colors', 'rica'),
                'desc'   => esc_html__('If you change value in this section, you must "Save & Generate CSS"', 'rica'),
                'icon'   => 'el el-magic',
                'fields' => array(
                    array(
                        'id'     => 'section-theme-color-general',
                        'type'   => 'section',
                        'title'  => esc_html__('General', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'accent_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Accent Color', 'rica'),
                        'default'  => '#ce2305',
                        'validate' => 'color',
                        'colors'   => array('#ce2305', '#a67d5e', '#313afa', '#ef5916', '#94650e', '#4285F4', '#2F659A', '#C60325', '#35BFEE', '#FFC40E', '#6EA9AD')
                    ),
                    array(
                        'id'       => 'foreground_accent_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Foregound Accent Color', 'rica'),
                        'default'  => '#fff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Text Color', 'rica'),
                        'default'  => '#787878',
                        'validate' => 'color',
                    ),

                    array(
                        'id'       => 'border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Border Color', 'rica'),
                        'default'  => '#eaeaea',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'heading_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Heading Color', 'rica'),
                        'default'  => '#232323',
                        'validate' => 'color',
                    ),
                    //--------------------------------------------------------------------
                    array(
                        'id'     => 'section-theme-color-top-drawer',
                        'type'   => 'section',
                        'title'  => esc_html__('Top Drawer', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'top_drawer_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top drawer background color', 'rica'),
                        'default'  => '#2f2f2f',
                        'validate' => 'color',
                    ),

                    array(
                        'id'       => 'top_drawer_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top drawer text color', 'rica'),
                        'default'  => '#c5c5c5',
                        'validate' => 'color',
                    ),

                    //--------------------------------------------------------------------
                    array(
                        'id'     => 'section-theme-color-header-color',
                        'type'   => 'section',
                        'title'  => esc_html__('Header', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'header_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header background color', 'rica'),
                        'default'  => '#fff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'header_overlay',
                        'type'     => 'slider',
                        'title'    => esc_html__('Header Overlay', 'rica'),
                        'subtitle' => esc_html__('Set the opacity level of the overlay', 'rica'),
                        'default'  => '0',
                        'min'      => 0,
                        'step'     => 1,
                        'max'      => 100,
                        'required' => array(
                            array('header_float', '=', 1),
                        ),
                    ),
                    array(
                        'id'       => 'header_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header text color', 'rica'),
                        'default'  => '#212121',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'header_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header border color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'header_above_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header above border color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),

                    //--------------------------------------------------------------------
                    array(
                        'id'     => 'section-theme-color-top-bar',
                        'type'   => 'section',
                        'title'  => esc_html__('Top Bar', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'top_bar_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top bar background color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'top_bar_overlay',
                        'type'     => 'slider',
                        'title'    => esc_html__('Top bar overlay', 'rica'),
                        'subtitle' => esc_html__('Set the opacity level of the overlay.', 'rica'),
                        'default'  => '0',
                        'min'      => 0,
                        'step'     => 1,
                        'max'      => 100,
                        'required' => array(
                            array('header_float', '=', 1),
                        ),
                    ),
                    array(
                        'id'       => 'top_bar_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top bar text color', 'rica'),
                        'default'  => '#777',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'top_bar_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top bar border color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),

                    //--------------------------------------------------------------------
                    array(
                        'id'     => 'section-theme-color-navigation-color',
                        'type'   => 'section',
                        'title'  => esc_html__('Navigation', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'navigation_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Navigation background color', 'rica'),
                        'default'  => '#fff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'navigation_overlay',
                        'type'     => 'slider',
                        'title'    => esc_html__('Navigation overlay', 'rica'),
                        'subtitle' => esc_html__('Set the opacity level of the overlay.', 'rica'),
                        'default'  => '0',
                        'min'      => 0,
                        'step'     => 1,
                        'max'      => 100,
                        'required' => array(
                            array('header_float', '=', 1),
                        )
                    ),
                    array(
                        'id'       => 'navigation_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Navigation text color', 'rica'),
                        'default'  => '#000000',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'navigation_text_color_hover',
                        'type'     => 'color',
                        'title'    => esc_html__('Navigation text hover color', 'rica'),
                        'default'  => '#ce2305',
                        'validate' => 'color',
                    ),

                    //--------------------------------------------------------------------
                    array(
                        'id'     => 'section-theme-color-header-mobile',
                        'type'   => 'section',
                        'title'  => esc_html__('Header Mobile Color', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'top_bar_mobile_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top bar background color', 'rica'),
                        'default'  => '#fff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'top_bar_mobile_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top bar text color', 'rica'),
                        'default'  => '#444',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'top_bar_mobile_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Top bar border bottom color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'header_mobile_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header background color', 'rica'),
                        'default'  => '#fff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'header_mobile_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header text color', 'rica'),
                        'default'  => '#444',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'header_mobile_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Header border bottom color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),

                    //--------------------------------------------------------------------
                    array(
                        'id'     => 'section-theme-color-footer-color',
                        'type'   => 'section',
                        'title'  => esc_html__('Footer', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'footer_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Footer background color', 'rica'),
                        'default'  => '#303030',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'footer_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Footer text color', 'rica'),
                        'default'  => '#888888',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'footer_widget_title_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Footer widget title color', 'rica'),
                        'default'  => '#fff',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'footer_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Footer border color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),
                    array(
                        'id'     => 'section-theme-color-bottom-bar-color',
                        'type'   => 'section',
                        'title'  => esc_html__('Bottom Bar', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'       => 'bottom_bar_bg_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Bottom bar background color', 'rica'),
                        'default'  => '#222222',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'bottom_bar_text_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Bottom bar text color', 'rica'),
                        'default'  => '#858585',
                        'validate' => 'color',
                    ),
                    array(
                        'id'       => 'bottom_bar_border_color',
                        'type'     => 'color',
                        'title'    => esc_html__('Bottom bar border color', 'rica'),
                        'default'  => '#eee',
                        'validate' => 'color',
                    ),
                )
            ));

            /**
             * Custom font Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Custom font', 'rica'),
                'desc'   => wp_kses_post(__('<span style="color:red"><strong>After upload font file, please click  "Save changes" and refresh page before go to Font Options</strong></span>', 'rica')),
                'icon'   => 'el el-text-width',
                'fields' => array(
                    array(
                        'id'     => 'section_custom_font_1',
                        'type'   => 'section',
                        'title'  => esc_html__('Custom Font 1', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'      => 'custom_font_1_name',
                        'type'    => 'text',
                        'title'   => esc_html__('Custom font Name 1', 'rica'),
                        'desc'    => '',
                        'default' => ''
                    ),
                    array(
                        'id'             => 'custom_font_1_eot',
                        'type'           => 'upload',
                        'url'            => true,
                        'title'          => esc_html__('Custom font 1 (.eot)', 'rica'),
                        'subtitle'       => esc_html__('Upload your font .eot here.', 'rica'),
                        'desc'           => '',
                        'library_filter' => array('eot')
                    ),
                    array(
                        'id'             => 'custom_font_1_ttf',
                        'type'           => 'upload',
                        'url'            => true,
                        'title'          => esc_html__('Custom font 1 (.ttf)', 'rica'),
                        'subtitle'       => esc_html__('Upload your font .ttf here.', 'rica'),
                        'desc'           => '',
                        'library_filter' => array('ttf')
                    ),
                    array(
                        'id'             => 'custom_font_1_woff',
                        'type'           => 'upload',
                        'url'            => true,
                        'title'          => esc_html__('Custom font 1 (.woff)', 'rica'),
                        'subtitle'       => esc_html__('Upload your font .woff here.', 'rica'),
                        'desc'           => '',
                        'library_filter' => array('woff')
                    ),
                    array(
                        'id'     => 'section_custom_font_2',
                        'type'   => 'section',
                        'title'  => esc_html__('Custom Font 2', 'rica'),
                        'indent' => true
                    ),
                    array(
                        'id'      => 'custom_font_2_name',
                        'type'    => 'text',
                        'title'   => esc_html__('Custom font Name 2', 'rica'),
                        'desc'    => '',
                        'default' => ''
                    ),
                    array(
                        'id'             => 'custom_font_2_eot',
                        'type'           => 'upload',
                        'url'            => true,
                        'title'          => esc_html__('Custom font 2 (.eot)', 'rica'),
                        'subtitle'       => esc_html__('Upload your font .eot here.', 'rica'),
                        'desc'           => '',
                        'library_filter' => array('eot')
                    ),
                    array(
                        'id'             => 'custom_font_2_ttf',
                        'type'           => 'upload',
                        'url'            => true,
                        'title'          => esc_html__('Custom font 2 (.ttf)', 'rica'),
                        'subtitle'       => esc_html__('Upload your font .ttf here.', 'rica'),
                        'desc'           => '',
                        'library_filter' => array('ttf')
                    ),
                    array(
                        'id'             => 'custom_font_2_woff',
                        'type'           => 'upload',
                        'url'            => true,
                        'title'          => esc_html__('Custom font 2 (.woff)', 'rica'),
                        'subtitle'       => esc_html__('Upload your font .woff here.', 'rica'),
                        'desc'           => '',
                        'library_filter' => array('woff')
                    )
                )
            ));

            /**
             * Font Options Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'icon'   => 'el el-font',
                'title'  => esc_html__('Font Options', 'rica'),
                'desc'   => esc_html__('If you change value in this section, you must "Save & Generate CSS"', 'rica'),
                'fields' => array(
                    array(
                        'id'             => 'body_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('Body Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the body font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'text-align'     => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'line-height'    => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('body'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '14px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '400',
                            'google'      => true
                        ),
                    ),
                    array(
                        'id'          => 'secondary_font',
                        'type'        => 'typography',
                        'title'       => esc_html__('Secondary Font', 'rica'),
                        'subtitle'    => esc_html__('Specify the Secondary font properties.', 'rica'),
                        'google'      => true,
                        'fonts'       => $fonts,
                        'line-height' => false,
                        'all_styles'  => true, // Enable all Google Font style/weight variations to be added to the page
                        'color'       => false,
                        'text-align'  => false,
                        'font-style'  => false,
                        'subsets'     => false,
                        'font-size'   => false,
                        'font-weight' => false,
                        'output'      => array(''), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'    => array(''), // An array of CSS selectors to apply this font style to dynamically
                        'units'       => 'px', // Defaults to px
                        'default'     => array(
                            'font-family' => 'Meddon',
                        ),
                    ),

                    array(
                        'id'             => 'h1_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H1 Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the H1 font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'text-align'     => false,
                        'line-height'    => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h1'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '36px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '600',
                        ),
                    ),
                    array(
                        'id'             => 'h2_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H2 Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the H2 font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'line-height'    => false,
                        'text-align'     => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h2'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h2'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '30px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '600',
                        ),
                    ),
                    array(
                        'id'             => 'h3_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H3 Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the H3 font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'text-align'     => false,
                        'line-height'    => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h3'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '20px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '700',
                        ),
                    ),
                    array(
                        'id'             => 'h4_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H4 Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the H4 font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'text-align'     => false,
                        'line-height'    => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h4'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '18px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '400',
                        ),
                    ),
                    array(
                        'id'             => 'h5_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H5 Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the H5 font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'line-height'    => false,
                        'text-align'     => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h5'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '16px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '600',
                        ),
                    ),
                    array(
                        'id'             => 'h6_font',
                        'type'           => 'typography',
                        'title'          => esc_html__('H6 Font', 'rica'),
                        'subtitle'       => esc_html__('Specify the H6 font properties.', 'rica'),
                        'google'         => true,
                        'fonts'          => $fonts,
                        'line-height'    => false,
                        'text-align'     => false,
                        'color'          => false,
                        'letter-spacing' => false,
                        'all_styles'     => true, // Enable all Google Font style/weight variations to be added to the page
                        'output'         => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                        'compiler'       => array('h6'), // An array of CSS selectors to apply this font style to dynamically
                        'units'          => 'px', // Defaults to px
                        'default'        => array(
                            'font-size'   => '14px',
                            'font-family' => 'Open Sans',
                            'font-weight' => '600',
                        ),
                    ),
                ),
            ));

            /**
             * Social Profiles Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Social Profiles', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-path',
                'fields' => array_merge(gf_get_social_profiles(), array(
                    array(
                        'id'   => 'social-profile-divide-0',
                        'type' => 'divide'
                    ),
                    array(
                        'title'    => esc_html__('Social Share', 'rica'),
                        'id'       => 'social_sharing',
                        'type'     => 'checkbox',
                        'subtitle' => esc_html__('Show the social sharing in single blog and single product', 'rica'),

                        //Must provide key => value pairs for multi checkbox options
                        'options'  => array(
                            'facebook'  => 'Facebook',
                            'twitter'   => 'Twitter',
                            'google'    => 'Google',
                            'linkedin'  => 'Linkedin',
                            'tumblr'    => 'Tumblr',
                            'pinterest' => 'Pinterest'
                        ),

                        //See how default has changed? you also don't need to specify opts that are 0.
                        'default'  => array(
                            'facebook'  => '1',
                            'twitter'   => '1',
                            'google'    => '1',
                            'linkedin'  => '1',
                            'tumblr'    => '1',
                            'pinterest' => '1'
                        )
                    )
                ))
            ));

            /**
             * Woocommerce Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Woocommerce', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-shopping-cart',
                'fields' => array(

                    $this->get_section_start('woocommerce_general', esc_html__('General', 'rica')),
                    array(
                        'id'       => 'product_featured_label_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Featured Label', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'product_featured_label_text',
                        'type'     => 'text',
                        'title'    => esc_html__('Featured Label Text', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'default'  => 'Hot',
                        'required' => array('product_featured_label_enable', '=', 1),
                    ),

                    array(
                        'id'       => 'product_sale_label_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Sale Label', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'product_sale_flash_mode',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Sale Flash Mode', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => array(
                            'text'    => esc_html__('Text', 'rica'),
                            'percent' => esc_html__('Percent', 'rica')
                        ),
                        'default'  => 'percent',
                        'required' => array('product_sale_label_enable', '=', 1),
                    ),

                    array(
                        'id'       => 'product_sale_label_text',
                        'type'     => 'text',
                        'title'    => esc_html__('Sale Label Text', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'default'  => 'Sale',
                        'required' => array(
                            array('product_featured_label_enable', '=', 1),
                            array('product_sale_flash_mode', '=', 'text'),
                        )
                    ),

                    array(
                        'id'       => 'product_add_to_cart_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Add To Cart Button', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    $this->get_section_start('archive_product', esc_html__('Shop and Category Page', 'rica')),
                    array(
                        'id'       => 'product_catalog_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Product Catalog', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),
                    array(
                        'id' => 'product_category_select',
                        'type' => 'select',
                        'multi' => true,
                        'title'    => esc_html__('Select Category Product', 'rica'),
                        'subtitle' => 'If empty, display all category',
                        'data' => 'category',
                        'args' => array(
                            'post_type' => 'product',
                            'taxonomy' => 'product_cat'
                        ),
                        'required' => array(
                            array('product_catalog_enable', '=', 1),
                        )

                    ),
                    array(
                        'id'       => 'product_sort_count_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Product Sort & Count', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),
                    array(
                        'id'       => 'product_display_columns',
                        'type'     => 'select',
                        'title'    => esc_html__('Product Display Columns', 'rica'),
                        'subtitle' => esc_html__('Choose the number of columns to display on shop/category pages.', 'rica'),
                        'options'  => array(
                            '2' => '2',
                            '3' => '3',
                            '4' => '4',
                        ),
                        'desc'     => '',
                        'default'  => '3',
                        'select2'  => array('allowClear' => false),
                    ),

                    array(
                        'id'          => 'product_per_page',
                        'type'        => 'text',
                        'title'       => esc_html__('Products Per Page', 'rica'),
                        'compiler'    => true,
                        'validate'    => 'comma_numeric',
                        'description' => esc_html__('Comma-seperated. 12,24,36', 'rica'),
                        'default'     => '12'
                    ),

                    array(
                        'id'       => 'product_image_hover_effect',
                        'type'     => 'select',
                        'title'    => esc_html__('Product Image Hover Effect', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_product_image_hover_effect(),
                        'default'  => 'change-image'
                    ),

                    array(
                        'id'       => 'product_category_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Category', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 0
                    ),

                    array(
                        'id'       => 'product_rating_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Rating', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    array(
                        'id'       => 'product_quick_view_enable',
                        'type'     => 'button_set',
                        'title'    => esc_html__('Show Quick View', 'rica'),
                        'subtitle' => '',
                        'desc'     => '',
                        'options'  => gf_get_toggle(),
                        'default'  => 1
                    ),

                    $this->get_section_start('single_product', esc_html__('Single Product', 'rica')),
                    array(
                        'id'       => 'related_product_count',
                        'type'     => 'text',
                        'title'    => esc_html__('Related Product Total Record', 'rica'),
                        'subtitle' => esc_html__('Total Record Of Related Product.', 'rica'),
                        'validate' => 'number',
                        'default'  => '6',
                    ),

                    array(
                        'id'       => 'related_product_display_columns',
                        'type'     => 'select',
                        'title'    => esc_html__('Related Product Display Columns', 'rica'),
                        'subtitle' => esc_html__('Choose the number of columns to display on related product.', 'rica'),
                        'options'  => array(
                            '3' => '3',
                            '4' => '4',
                        ),
                        'desc'     => '',
                        'default'  => '4'
                    ),

                    array(
                        'id'      => 'related_product_condition',
                        'type'    => 'checkbox',
                        'title'   => esc_html__('Related Product Condition', 'rica'),
                        'options' => array(
                            'category' => esc_html__('Same Category', 'rica'),
                            'tag'      => esc_html__('Same Tag', 'rica'),
                        ),
                        'default' => array(
                            'category' => '1',
                            'tag'      => '1',
                        ),
                    ),

                    array(
                        'id'       => 'up_sells_product_display_columns',
                        'type'     => 'select',
                        'title'    => esc_html__('Up Sells Product Display Columns', 'rica'),
                        'subtitle' => esc_html__('Choose the number of columns to display on up sells product.', 'rica'),
                        'options'  => array(
                            '3' => '3',
                            '4' => '4',
                        ),
                        'desc'     => '',
                        'default'  => '4'
                    ),
                    $this->get_section_start('cart_pages', esc_html__('Cart Page', 'rica')),
                    array(
                        'id'       => 'cross_sells_product_count',
                        'type'     => 'text',
                        'title'    => esc_html__('Cross Sells Product Total Record', 'rica'),
                        'subtitle' => esc_html__('Total Record Of Cross Sells Product.', 'rica'),
                        'validate' => 'number',
                        'default'  => '6',
                    ),

                    array(
                        'id'       => 'cross_sells_product_display_columns',
                        'type'     => 'select',
                        'title'    => esc_html__('Cross Sells Product Display Columns', 'rica'),
                        'subtitle' => esc_html__('Choose the number of columns to display on cross sells product.', 'rica'),
                        'options'  => array(
                            '3' => '3',
                            '4' => '4',
                        ),
                        'desc'     => '',
                        'default'  => '4'
                    ),

                )
            ));
            /**
             * Resources Options Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Resources Options', 'rica'),
                'desc'   => '',
                'icon'   => 'el el-th-large',
                'fields' => array(
                    array(
                        'id'       => 'cdn_bootstrap_js',
                        'type'     => 'text',
                        'title'    => esc_html__('CDN Bootstrap Script', 'rica'),
                        'subtitle' => esc_html__('Url CDN Bootstrap Script', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                    ),

                    array(
                        'id'       => 'cdn_bootstrap_css',
                        'type'     => 'text',
                        'title'    => esc_html__('CDN Bootstrap Stylesheet', 'rica'),
                        'subtitle' => esc_html__('Url CDN Bootstrap Stylesheet', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                    ),

                    array(
                        'id'       => 'cdn_font_awesome',
                        'type'     => 'text',
                        'title'    => esc_html__('CDN Font Awesome', 'rica'),
                        'subtitle' => esc_html__('Url CDN Font Awesome', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                    ),

                )
            ));

            /**
             * Custom CSS & Script Section
             * *******************************************************
             */
            Redux::setSection($opt_name, array(
                'title'  => esc_html__('Custom CSS & Script', 'rica'),
                'desc'   => esc_html__('If you change Custom CSS, you must "Save & Generate CSS"', 'rica'),
                'icon'   => 'el el-edit',
                'fields' => array(
                    array(
                        'id'       => 'custom_css',
                        'type'     => 'ace_editor',
                        'mode'     => 'css',
                        'theme'    => 'monokai',
                        'title'    => esc_html__('Custom CSS', 'rica'),
                        'subtitle' => esc_html__('Add some CSS to your theme by adding it to this textarea. Please do not include any style tags.', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 20, 'maxLines' => 60)
                    ),
                    array(
                        'id'       => 'custom_js',
                        'type'     => 'ace_editor',
                        'mode'     => 'javascript',
                        'theme'    => 'chrome',
                        'title'    => esc_html__('Custom JS', 'rica'),
                        'subtitle' => esc_html__('Add some custom JavaScript to your theme by adding it to this textarea. Please do not include any script tags.', 'rica'),
                        'desc'     => '',
                        'default'  => '',
                        'options'  => array('minLines' => 20, 'maxLines' => 60)
                    ),

                )
            ));

	        /**
	         * Preset Settings Section
	         * *******************************************************
	         */
	        Redux::setSection( $opt_name, array(
		        'title'  => esc_html__( 'Preset Settings', 'rica' ),
		        'desc'   => esc_html__( 'Choose Preset Setting apply for page type', 'rica' ),
		        'icon'   => 'el el-edit',
		        'fields' => array_merge(
			        array(
				        array(
					        'id' => 'blog_preset',
					        'type' => 'select',
					        'data' => 'post',
					        'title' => esc_html__('Blog Preset', 'rica'),
					        'placeholder' => esc_html__('Select Preset...', 'rica'),
					        'default' => '',
					        'args' => array(
						        'post_type' => 'gf_preset',
                                'numberposts' => -1
					        )
				        ),
				        array(
					        'id' => 'blog_single_preset',
					        'type' => 'select',
					        'data' => 'posts',
					        'title' => esc_html__('Blog Single Preset', 'rica'),
					        'placeholder' => esc_html__('Select Preset...', 'rica'),
					        'default' => '',
					        'args' => array(
						        'post_type' => 'gf_preset',
                                'numberposts' => -1
					        )
				        ),
				        array(
					        'id' => 'divide_preset_setting_1',
					        'type' => 'divide',
				        ),
				        array(
					        'id' => 'product_preset',
					        'type' => 'select',
					        'data' => 'posts',
					        'title' => esc_html__('Product Preset', 'rica'),
					        'placeholder' => esc_html__('Select Preset...', 'rica'),
					        'default' => '',
					        'args' => array(
						        'post_type' => 'gf_preset',
                                'numberposts' => -1
					        )
				        ),
				        array(
					        'id' => 'product_single_preset',
					        'type' => 'select',
					        'data' => 'posts',
					        'title' => esc_html__('Product Single Preset', 'rica'),
					        'placeholder' => esc_html__('Select Preset...', 'rica'),
					        'default' => '',
					        'args' => array(
						        'post_type' => 'gf_preset',
                                'numberposts' => -1
					        )
				        ),
                        array(
                            'id' => 'event_preset',
                            'type' => 'select',
                            'data' => 'posts',
                            'title' => esc_html__('Event Preset', 'rica'),
                            'placeholder' => esc_html__('Select Preset...', 'rica'),
                            'default' => '',
                            'args' => array(
                                'post_type' => 'gf_preset',
                                'numberposts' => -1
                            )
                        ),
                        array(
                            'id' => 'event_single_preset',
                            'type' => 'select',
                            'data' => 'posts',
                            'title' => esc_html__('Event Single Preset', 'rica'),
                            'placeholder' => esc_html__('Select Preset...', 'rica'),
                            'default' => '',
                            'args' => array(
                                'post_type' => 'gf_preset',
                                'numberposts' => -1
                            )
                        ),
			        ),
					$post_type_preset_list,
			        array(
				        array(
					        'id' => 'divide_preset_setting_2',
					        'type' => 'divide',
				        ),
				        array(
					        'id' => 'page_404_preset',
					        'type' => 'select',
					        'data' => 'posts',
					        'title' => esc_html__('404 Page Preset', 'rica'),
					        'placeholder' => esc_html__('Select Preset...', 'rica'),
					        'default' => '',
					        'args' => array(
						        'post_type' => 'gf_preset',
                                'numberposts' => -1
					        )
				        ),
			        )
		        )
	        ));
        }
    }

    new GF_Options_Config();
}