<?php
/**
 * Shortcode attributes
 * @var $atts
 * @var $layout
 * @var $feature_image
 * @var $add_video
 * @var $link_video
 * @var $title
 * @var $add_icon
 * @var $icon_type
 * @var $icon_font
 * @var $icon_image
 * @var $description
 * @var $link
 * @var $color_scheme
 * @var $css_animation
 * @var $animation_duration
 * @var $animation_delay
 * @var $el_class
 * @var $css
 * Shortcode class
 * @var $this WPBakeryShortCode_G5Plus_Feature_Box
 */
$atts = vc_map_get_attributes($this->getShortcode(), $atts);
$wrapper_attributes = array();
$wrapper_styles = array();

$wrapper_classes = array(
    'g5plus-feature-box',
    'fb-layout-' . $atts['layout'],
    'clearfix',
    $this->getExtraClass($atts['el_class']),
    $this->getCSSAnimation($atts['css_animation'])
);

/*Feature Image*/
if (!empty($atts['feature_image'])) {
    $bg_images_attr = wp_get_attachment_image_src($atts['feature_image'], "full");
    if (isset($bg_images_attr)) {
        $img_url = $bg_images_attr[0];
        $img_resize = matthewruddy_image_resize($img_url, 570, 431);
        $img_resize_url = is_array($img_resize) ? $img_resize['url'] : '';
    }
}


$animation_style = $this->getStyleAnimation($atts['animation_duration'], $atts['animation_delay']);
if (sizeof($animation_style) > 0) {
    $wrapper_styles = $animation_style;
}

$link_attributes = array();
$atts['link'] = ( '||' === $atts['link'] ) ? '' : $atts['link'];
$atts['link'] = vc_build_link( $atts['link'] );
$use_link = false;
if ( strlen( $atts['link']['url'] ) > 0 ) {
    $use_link = true;
    $a_href = $atts['link']['url'];
    if(!empty($atts['link']['title'])){
        $a_title = $atts['link']['title'];
    }else{
        $a_title = "Read More";
    }
    $a_target = $atts['link']['target'];
} else {
    $a_href = '';
}

$link_attributes[] = 'href="' . esc_url( trim( $a_href ) ) . '"';
if (!empty($a_title)) {
    $link_attributes[] = 'title="' . esc_attr( trim( $a_title ) ) . '"';
}
if ( ! empty( $a_target ) ) {
    $link_attributes[] = 'target="' . esc_attr( trim( $a_target ) ) . '"';
}

// icon html
if($atts['add_icon'] == 'yes'){
    $icon_html = '';
    $icon_attributes = array();
    if ($atts['icon_type'] == 'image') {
        if (!empty($atts['icon_image'])) {
            $icon_image_id = preg_replace( '/[^\d]/', '', $atts['icon_image'] );
            $icon_image_src = wp_get_attachment_image_src( $icon_image_id, 'full' );
            if ( ! empty( $icon_image_src[0] ) ) {
                $icon_image_src = $icon_image_src[0];
                $icon_html = '<img alt="'. the_title_attribute(array('post' => $icon_image_id,'echo' => false )) .'" src="'. esc_url($icon_image_src) .'">';
            }
        }
    } else {
        $icon_html = '<i '. implode(' ',$icon_attributes) .' class="'. esc_attr($atts['icon_font']).'"></i>';
    }
}

if ($wrapper_styles) {
    $wrapper_attributes[] = 'style="' . implode('; ', $wrapper_styles) . '"';
}

$class_to_filter = implode(' ',$wrapper_classes);
$class_to_filter .= vc_shortcode_custom_css_class($atts['css'], ' ');
$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter, $this->settings['base'], $atts);

if (!(defined('G5PLUS_SCRIPT_DEBUG') && G5PLUS_SCRIPT_DEBUG)) {
    $min_suffix = gf_get_option('enable_minifile_css',0) == 1 ? '.min' : '';
    wp_enqueue_style(GF_PLUGIN_PREFIX . 'feature-box', plugins_url(GF_PLUGIN_NAME . '/shortcodes/feature-box/assets/css/feature-box'.$min_suffix.'.css'), array(), false, 'all');
}
?>
<div class="<?php echo esc_attr($css_class) ?>" <?php echo implode(' ', $wrapper_attributes); ?>>
    <?php if($atts['layout'] == 'default'):?>
        <?php if(!empty($img_url)):?>
            <div class="feature-thumbnail">
                <div class="captions">
                    <a href="<?php echo esc_url($img_url)?>" class="jg-entry">
                        <img src="<?php echo esc_url($img_resize_url) ?>" alt="">
                    </a>
                </div>
                <?php if($atts['add_video'] == 'yes' && (!empty($atts['link_video']))):?>
                    <div class="play-video lightgallery-video">
                        <a class="light-video" href="<?php echo esc_url($atts['link_video'])?>"><i class="fa fa-play"></i></a>
                    </div>
                <?php endif; ?>
            </div>
        <?php endif;?>
        <div class="feature-content">
            <?php if(!empty($atts['title'])):?>
                <div class="title">
                    <?php if($atts['add_icon'] == 'yes'):?>
                        <?php echo wp_kses_post($icon_html); ?>
                    <?php endif;?>
                    <h3>
                        <?php if(!empty($a_href) && $a_href != '#'):?>
                            <a href="<?php echo esc_url($a_href) ?>"><?php echo esc_html($atts['title'])?></a>
                        <?php else:?>
                            <?php echo esc_html($atts['title'])?>
                        <?php endif;?>
                    </h3>
                </div>
            <?php endif;?>
            <?php if(!empty($atts['description'])):?>
                <p>
                    <?php echo esc_html($atts['description'])?>
                </p>
            <?php endif;?>
            <?php if(!empty($a_href) && $a_href != '#'):?>
                <a class="read-more-feature" href="<?php echo esc_url($a_href); ?>">
                    <?php echo esc_html($a_title)?>
                </a>
            <?php endif;?>
        </div>
    <?php endif;?>
</div>
