<?php
/**
 * Shortcode attributes
 * @var $atts
 * @var $show
 * @var $category
 * @var $number
 * @var $columns
 * @var $orderby
 * @var $order
 * @var $is_slider
 * @var $arrows
 * @var $dots
 * @var $arrows_position
 * @var $arrows_style
 * @var $custom_catalog_style_enable
 * @var $product_catalog_style
 * @var $product_category_enable
 * @var $product_sale_count_down_enable
 * @var $column_gap
 * @var $css_animation
 * @var $animation_duration
 * @var $animation_delay
 * @var $el_class
 * @var $css
 * @var $items_md
 * @var $items_sm
 * @var $items_xs
 * @var $items_mb
 * Shortcode class
 * @var $this WPBakeryShortCode_G5Plus_Products
 */

$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
$wrapper_attributes = array();
$styles = array();
global $product, $woocommerce_loop;
$woocommerce_loop['name'] = 'shortcode-product';
$wrapper_classes = array(
	'woocommerce',
	'g5plus-products',
	'clearfix',
	$this->getExtraClass( $atts['el_class'] ),
	$this->getCSSAnimation( $atts['css_animation'] )
);

// animation
$animation_style = $this->getStyleAnimation($atts['animation_duration'],$atts['animation_delay']);
if (sizeof($animation_style) > 0) {
	$styles = $animation_style;
}

if ( $styles ) {
	$wrapper_attributes[] = 'style="' . implode( ' ', $styles ) . '"';
}

// get sources
$product_visibility_term_ids = wc_get_product_visibility_term_ids();
$query_args = array(
    'posts_per_page' => intval($atts['number']),
    'post_status'    => 'publish',
    'post_type'      => 'product',
    'no_found_rows'  => 1,
    'meta_query'     => array(),
    'tax_query'      => array(
        'relation' => 'AND',
        array(
            'taxonomy' => 'product_visibility',
            'field'    => 'term_taxonomy_id',
            'terms'    => is_search() ? $product_visibility_term_ids['exclude-from-search'] : $product_visibility_term_ids['exclude-from-catalog'],
            'operator' => 'NOT IN',
        )
    ),
    'post_parent'  => 0
);


if (!empty($atts['category']) && ($atts['show'] != 'products')) {
	$query_args['tax_query'] = array(
		array(
			'taxonomy' 		=> 'product_cat',
			'terms' 		=>  explode(',',$atts['category']),
			'field' 		=> 'slug',
			'operator' 		=> 'IN'
		)
	);
}

switch($atts['show']) {
	case 'sale':
		$product_ids_on_sale = wc_get_product_ids_on_sale();
		$query_args['post__in'] = array_merge( array( 0 ), $product_ids_on_sale );
		break;
	case 'new-in':
		$query_args['orderby'] = 'DESC';
		$query_args['order'] = 'date';
		break;
	case 'featured':
        $query_args['tax_query'][] = array(
            'taxonomy' => 'product_visibility',
            'field'    => 'term_taxonomy_id',
            'terms'    => $product_visibility_term_ids['featured'],
        );
		break;
	case 'top-rated':
        $query_args['meta_key'] = '_wc_average_rating';
        $query_args['orderby'] = 'meta_value_num';
        $query_args['order'] = 'DESC';
        $query_args['meta_query'] = WC()->query->get_meta_query();
        $query_args['tax_query'] = WC()->query->get_tax_query();
		break;
	case 'recent-review':
		add_filter( 'posts_clauses', array($this, 'order_by_comment_date_post_clauses' ) );
		break;
	case 'best-selling' :
		$query_args['meta_key'] = 'total_sales';
		$query_args['orderby'] = 'meta_value_num';
		break;
}

if (in_array($atts['show'],array('all','sale','featured'))) {
	$query_args['order'] = $atts['order'];
	switch ( $atts['orderby'] ) {
		case 'price' :
			$query_args['meta_key'] = '_price';
			$query_args['orderby']  = 'meta_value_num';
			break;
		case 'rand' :
			$query_args['orderby']  = 'rand';
			break;
		case 'sales' :
			$query_args['meta_key'] = 'total_sales';
			$query_args['orderby']  = 'meta_value_num';
			break;
		default :
			$query_args['orderby']  = 'date';
	}
}

$r = new WP_Query( apply_filters( 'woocommerce_shortcode_products_query', $query_args, $atts ) );

if($atts['show'] =='recent-review' ){
	remove_filter( 'posts_clauses', array($this, 'order_by_comment_date_post_clauses' )  );
}

$totalRecord = $r->post_count;
$per_page =  $atts['columns'];
$index = 0;
$index_sub = 0;
$woocommerce_loop['columns'] = $atts['columns'];
if ($atts['is_slider']) {
	$wrapper_classes[] = 'owl-carousel';
	$slider_attributes = '';
	$slider_attributes = array(
		'"items":'.$atts['columns'],
		'"nav": ' . ($atts['arrows'] ? 'true' : 'false'),
		'"dots":' . ($atts['dots'] ? 'true' : 'false'),
		'"loop": false',
		'"responsive": {"0":{"items": 1},"320":{"items": '.$atts['items_mb'].'},"480":{"items":'.$atts['items_xs'].'},"600":{"items": '.$atts['items_sm'].'},"991":{"items": '.$atts['items_md'].'},"1200":{"item": '.$atts['columns'].'}}',
	);
	 $data_plugin_options = "data-plugin-options='{" . implode(', ', $slider_attributes) . "}'";
}

$class_to_filter = implode(' ', $wrapper_classes);
$class_to_filter .= vc_shortcode_custom_css_class($atts['css'], ' ');
$css_class = apply_filters(VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter, $this->settings['base'], $atts);
wp_enqueue_style(GF_PLUGIN_PREFIX . 'products', plugins_url(GF_PLUGIN_NAME . '/shortcodes/products/assets/css/products' . $min_suffix . '.css'), array(), false, 'all');
?>
<div class="<?php echo esc_attr($css_class) ?>" <?php echo sprintf('%s',$data_plugin_options); ?> <?php echo implode( ' ', $wrapper_attributes ); ?>>
	<?php if ($r->have_posts()): ?>
		<?php while ( $r->have_posts() ) : $r->the_post(); ?>
			<?php GF_FrameWork_CPT::get_shortcode_template("products/content-product",$atts); ?>
		<?php endwhile; // end of the loop. ?>
		<?php if (($atts['is_slider']) && ($totalRecord > $per_page) && ($index_sub != $per_page) && ($index > 0)) : ?>
			</div><!-- End Loop -->
		<?php endif; ?>
	<?php else: ?>
		<div class="item-not-found"><?php esc_html_e('No item found','rica'); ?></div>
	<?php endif; ?>
</div>
<?php wp_reset_postdata(); ?>