<?php
/**
 * The template for displaying page title
 *
 * @package WordPress
 * @subpackage Theme_Name
 * @since Theme_Version 1.0
 */

global $post;

$page_title = '';
$page_sub_title = '';
$page_title_enable = 1;
$page_breadcrumbs_enable = 1;
$page_title_bg_image = '';
$post_type_title = '';

$page_id = isset($post) ? $post->ID : null;
if (function_exists('wc_get_page_id') &&
    ((function_exists('is_shop') && is_shop())
        || (function_exists('is_product_category') && is_product_category())
        || (function_exists('is_product_tag') && is_product_tag())
    )
) {
    $page_id = wc_get_page_id('shop');
}
if (is_home()) {
    $page_id = get_option('page_for_posts');
}
if (is_front_page()) {
    $page_id = get_option('page_on_front');
}

$page_title_layout = g5plus_get_option('page_title_layout', 'normal');
$page_title_padding = g5plus_get_option('page_title_padding', array('padding-top' => '70', 'padding-bottom' => '70', 'units' => 'px'));
$page_title_parallax = g5plus_get_option('page_title_parallax', 1);
if (is_home() || is_front_page()) {
    if ($page_title === '') {
        $page_title = esc_html__("Our Blog", 'rica');
        $post_type_title = esc_html__('News', 'rica');
    }
} elseif (!is_singular() && !is_front_page()) {
    if (!empty($page_sub_title)) {
        $page_sub_title = strip_tags(term_description());
    }
    if (function_exists('is_shop') && is_shop()) {
        if (empty($page_title)) {
            $page_title = 'Our Shop';
        }
    }
    if (!have_posts()) {
        if (is_search()) {
            $page_title = esc_html__('Nothing Found', 'rica');
        }
        if (is_404()) {
            $page_title = esc_html__('ERROR', 'rica');
        }

    } elseif (is_tag() || is_tax('product_tag')) {
        $page_title = single_tag_title(esc_html__("Tags: ", 'rica'), false);
    } elseif (is_category() || is_tax()) {
        $page_title = single_cat_title('', false);
    } elseif (is_author()) {
        $page_title = sprintf(esc_html__('Author: %s', 'rica'), get_the_author());
    } elseif (is_day()) {
        $page_title = sprintf(esc_html__('Daily Archives: %s', 'rica'), get_the_date());
    } elseif (is_month()) {
        $page_title = sprintf(esc_html__('Monthly Archives: %s', 'rica'), get_the_date(_x('F Y', 'monthly archives date format', 'rica')));
    } elseif (is_year()) {
        $page_title = sprintf(esc_html__('Yearly Archives: %s', 'rica'), get_the_date(_x('Y', 'yearly archives date format', 'rica')));
    } elseif (is_search()) {
        $page_title = sprintf(esc_html__('Search Results: &ldquo;%s&rdquo;', 'rica'), get_search_query());
    } elseif (is_tax('post_format', 'post-format-aside')) {
        $page_title = esc_html__('Asides', 'rica');
    } elseif (is_tax('post_format', 'post-format-gallery')) {
        $page_title = esc_html__('Galleries', 'rica');
    } elseif (is_tax('post_format', 'post-format-image')) {
        $page_title = esc_html__('Images', 'rica');
    } elseif (is_tax('post_format', 'post-format-video')) {
        $page_title = esc_html__('Videos', 'rica');
    } elseif (is_tax('post_format', 'post-format-quote')) {
        $page_title = esc_html__('Quotes', 'rica');
    } elseif (is_tax('post_format', 'post-format-link')) {
        $page_title = esc_html__('Links', 'rica');
    } elseif (is_tax('post_format', 'post-format-status')) {
        $page_title = esc_html__('Statuses', 'rica');
    } elseif (is_tax('post_format', 'post-format-audio')) {
        $page_title = esc_html__('Audios', 'rica');
    } elseif (is_tax('post_format', 'post-format-chat')) {
        $page_title = esc_html__('Chats', 'rica');
    }

    $cat = get_queried_object();
    // custom page title background
    if ($cat && property_exists($cat, 'term_id')) {
        $page_title_enable = g5plus_get_tax_meta($cat->term_id, 'page_title_enable');
        if ($page_title_enable != '' && $page_title_enable != -1) {
            return;
        }
        $bg_image = g5plus_get_tax_meta($cat->term_id, 'page_title_bg_image');
        if (isset($bg_image['url'])) {
            $page_title_bg_image = $bg_image['url'];
        }
    }
}

$page_title_post_type = get_post_type($page_id);
switch ($page_title_post_type) {
    case 'post':
        $post_type_title = esc_html__('News', 'rica');
        break;
    case 'product':
        $post_type_title = esc_html__('Shop', 'rica');
        break;
    case 'tribe_events':
        $post_type_title = esc_html__('Events', 'rica');
        break;
    case 'page':
        $post_type_title = esc_html__('Page', 'rica');
        break;
    case 'menu':
        $post_type_title = esc_html__('Menu', 'rica');
        break;
    case 'gallery':
        $post_type_title = esc_html__('Gallery', 'rica');
        break;
    default:
        if (is_search()) {
            $post_type_title = esc_html__('Search Page', 'rica');
        }
        if (is_404()) {
            $post_type_title = esc_html__('404 Page', 'rica');
        }
        break;
}


$page_sub_title = $post_type_title;

$page_title_enable = g5plus_get_rwmb_meta('custom_page_title_visible', array(), $page_id);
if ($page_title_enable === '-1' || $page_title_enable === '' || is_404() || is_search() || is_singular('tribe_events')) {
    $page_title_enable = g5plus_get_option('page_title_enable', 1);
}

if (!$page_title_enable)
    return;

$page_breadcrumbs_enable = g5plus_get_rwmb_meta('custom_breadcrumbs_visible', array(), $page_id);
if ($page_breadcrumbs_enable === '-1' || is_404() || $page_breadcrumbs_enable == '') {
    $page_breadcrumbs_enable = g5plus_get_option('breadcrumbs_enable', 1);
}
$page_breadcrumbs_enable = apply_filters('page_breadcrumbs_enable', $page_breadcrumbs_enable);


if (g5plus_get_rwmb_meta('is_custom_page_title', array(), $page_id) == '1') {
    $page_title = g5plus_get_rwmb_meta('custom_page_title', array(), $page_id);
    $page_sub_title = g5plus_get_rwmb_meta('custom_page_sub_title', array(), $page_id);

} else {
    $page_title_meta = g5plus_get_option('page_title', $page_title);
    $page_sub_title_meta = g5plus_get_option('page_sub_title', $page_sub_title);
    if ($page_title_meta) {
        $page_title = $page_title_meta;
    }
    if (!$page_title) {
        $page_title = get_the_title(get_the_ID());
    }
    $page_sub_title = $page_sub_title_meta ? $page_sub_title_meta : $page_sub_title;
}


if (g5plus_get_rwmb_meta('is_custom_page_title_bg', array(), $page_id) == '1') {
    $page_title_bg_image = g5plus_get_rwmb_meta_image('custom_page_title_bg_image', array(), $page_id);
} else {
    $url = G5PLUS_THEME_URL . '/assets/images/page-title.jpg';
    $page_title_bg_image = g5plus_get_option('page_title_bg_image', array('url' => $url));
    $page_title_bg_image = isset($page_title_bg_image['url']) ? $page_title_bg_image['url'] : '';
}

if (is_singular('tribe_events') && function_exists('tribe_get_events_title')){
    $page_sub_title = esc_html__('Events', 'rica');
    $page_title = tribe_get_events_title();
    if (g5plus_get_rwmb_meta('is_custom_page_title', array(), $page_id) == '1') {
        $page_title = g5plus_get_rwmb_meta('custom_page_title', array(), $page_id);
        $page_sub_title = g5plus_get_rwmb_meta('custom_page_sub_title', array(), $page_id);

    } else {
        $page_title_meta = g5plus_get_option('page_title', $page_title);
        $page_sub_title_meta = g5plus_get_option('page_sub_title', $page_sub_title);
        if ($page_title_meta) {
            $page_title = $page_title_meta;
        }
        if (!$page_title) {
            $page_title = get_the_title(get_the_ID());
        }
        $page_sub_title = $page_sub_title_meta ? $page_sub_title_meta : $page_sub_title;
    }
}

$page_title = apply_filters('g5plus_page_title', $page_title);
$page_sub_title = apply_filters('g5plus_sub_page_title', $page_sub_title);

if (!empty($page_sub_title)) {
    $page_title_text_top = $page_sub_title;
}


$page_title_class = array('page-title');
$page_title_class[] = 'page-title-layout-' . $page_title_layout;

// region Custom Styles

$custom_styles = array();
$page_title_padding['units'] = isset($page_title_padding['units']) ? $page_title_padding['units'] : 'px';
if (isset($page_title_padding['padding-top']) && !empty($page_title_padding['padding-top']) && ($page_title_padding['padding-top'] != 'px')) {
    $custom_styles[] = "padding-top:" . $page_title_padding['padding-top'] . (!strrpos($page_title_padding['padding-top'],'px') ? $page_title_padding['units'] : '');
}
if (isset($page_title_padding['padding-bottom']) && !empty($page_title_padding['padding-bottom']) && ($page_title_padding['padding-bottom'] != 'px')) {
    $custom_styles[] = "padding-bottom:" . $page_title_padding['padding-bottom'] . (!strrpos($page_title_padding['padding-top'],'px') ? $page_title_padding['units'] : '');
}
if (!empty($page_title_bg_image)) {
    $custom_styles[] = 'background-image: url(' . $page_title_bg_image . ')';
    $page_title_class[] = 'page-title-background';

    if ($page_title_parallax) {
        $page_title_class[] = 'parallax';
    }
}
$custom_style = '';
if ($custom_styles) {
    $custom_style = 'style="' . join(';', $custom_styles) . '"';
}
if (!empty($page_title_bg_image) && $page_title_parallax) {
    $custom_style .= ' data-stellar-background-ratio="0.5"';
}

// endregion
?>
<section class="<?php echo join(' ', $page_title_class); ?>" <?php echo wp_kses_post($custom_style); ?>>
    <div class="container">
        <div class="page-title-inner">
            <?php if ($page_sub_title): ?>
                <p><?php echo esc_html($page_sub_title) ?></p>
            <?php endif; ?>
            <h1><?php echo esc_html($page_title) ?></h1>
            <?php if ($page_breadcrumbs_enable) : ?>
                <?php get_template_part('templates/breadcrumb'); ?>
            <?php endif; ?>
        </div>
    </div>
</section>