<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.4.0
 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}
$args = isset($args) ? $args: array();
if (!isset($args['ajax']))
    get_header('shop');


global $wp_query,$product;
$item_default = g5plus_get_option('product_per_page', 12);
$current_page = isset($args['current_page']) && $args['current_page'] ? $args['current_page'] : 1;
$posts_per_page = isset($args['items']) ? $args['items'] : $item_default;
if(isset($_REQUEST['items'])){
    $posts_per_page= $_REQUEST['items'];
}
$attr = isset($args['addition_attr']) ? $args['addition_attr'] : array();
$addition_attr = array();
if(!isset($args['ajax']) || intval($args['ajax']) !== 1) {
    $query_str = $_SERVER['QUERY_STRING'];
    $query_str = explode('&', $query_str);
    if (count($query_str) > 0) {
        foreach ($query_str as $attr) {
            $attr = explode('=', $attr);
            $key = isset($attr[0]) ? $attr[0] : '';
            $value = isset($attr[1]) ? $attr[1] : '';
            $addition_attr[$key] = $value;
        }
    }
} else {
    $addition_attr = $attr;
}
$wp_query = apply_filters('woocommerce_pre_set_query',$wp_query,$args);


?>

<?php
/**
 * woocommerce_before_main_content hook.
 *
 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
 * @hooked woocommerce_breadcrumb - 20
 */
do_action('woocommerce_before_main_content');
?>

<?php if (apply_filters('woocommerce_show_page_title', true)) : ?>

    <h1 class="page-title"><?php woocommerce_page_title(); ?></h1>

<?php endif; ?>

<?php
/**
 * woocommerce_archive_description hook.
 *
 * @hooked woocommerce_taxonomy_archive_description - 10
 * @hooked woocommerce_product_archive_description - 10
 */
do_action('woocommerce_archive_description');
?>
<?php
$total_post = $wp_query->found_posts;
$total_page = floor($total_post / $posts_per_page);
if ($total_post % $posts_per_page > 0) {
    $total_page += 1;
}

?>

<?php
if ( woocommerce_product_loop() ) {

    /**
     * Hook: woocommerce_before_shop_loop.
     *
     * @hooked wc_print_notices - 10
     * @hooked woocommerce_result_count - 20
     * @hooked woocommerce_catalog_ordering - 30
     */
    do_action( 'woocommerce_before_shop_loop' );

    woocommerce_product_loop_start();

    if ( wc_get_loop_prop( 'total' ) || isset($args['ajax']) ) {
        while ( have_posts() ) {
            the_post();

            /**
             * Hook: woocommerce_shop_loop.
             *
             * @hooked WC_Structured_Data::generate_product_data() - 10
             */
            do_action( 'woocommerce_shop_loop' );

            wc_get_template_part( 'content', 'product' );
        }
    }

    woocommerce_product_loop_end();

    /**
     * Hook: woocommerce_after_shop_loop.
     *
     * @hooked woocommerce_pagination - 10
     */
    do_action( 'woocommerce_after_shop_loop' );
} else {
    /**
     * Hook: woocommerce_no_products_found.
     *
     * @hooked wc_no_products_found - 10
     */
    do_action( 'woocommerce_no_products_found' );
}
?>

<?php
$loop_style = isset($woocommerce_loop['name']) ? $woocommerce_loop['name'] : '';
$cate = '';
if ($loop_style != 'related' && $loop_style != 'up-sells' && $loop_style != 'cross-sells') :
    if (isset($args['cate']) && $args['cate']) {
        $cate = $args['cate'];
    }else{
        if(empty($cate) && g5plus_get_option('product_catalog_enable') == 1){
            $cate = g5plus_get_option('product_category_select');
            $all_cate_select = array();
            if(!empty($cate)){
                foreach ($cate as $cat){
                    $cate_select = get_term($cat,'product_cat');
                    $category_slug = $cate_select->slug;
                    $all_cate_select[] = $category_slug;
                }
                $cate = esc_attr(implode(',', $all_cate_select));
            }
        } else {
            global $wp_query;
            $cat = isset($wp_query->query_vars['product_cat']) ? $wp_query->query_vars['product_cat'] : '';
            if (!empty($cat)) {
                $cate = $cat;
            }
        }
    }
    $align_cate = g5plus_get_option('product_catalog_style');
    //$item_per_page = g5plus_get_option('product_per_page');
    $archive_columns = g5plus_get_option('product_display_columns',4);
    $show_rating = g5plus_get_option('product_rating_enable',0);
    $show_quick_view = g5plus_get_option('product_quick_view_enable',0); ?>
    <div class="button-view-more-wrap" data-category="<?php echo esc_attr($cate) ?>"
         data-current-page="<?php echo esc_attr($current_page) ?>"
         data-align-cate="<?php echo esc_attr($align_cate) ?>"
         data-item-perpage="<?php echo esc_attr($posts_per_page) ?>"
         data-columns="<?php echo esc_attr($archive_columns) ?>" data-show-rating="<?php echo esc_attr($show_rating) ?>"
         data-show-quickview="<?php echo esc_attr($show_quick_view) ?>"
         data-max-page="<?php echo esc_attr($total_page) ?>"
         data-addition-attr='<?php echo json_encode($addition_attr); ?>'
    >
        <?php if ($total_page > $current_page) : ?>
            <a href="javascript:;" class="button button-view-more">
                <?php esc_html_e('View More','rica'); ?>
            </a>
        <?php endif; ?>
    </div>
<?php endif; ?>
<?php
/**
 * woocommerce_after_main_content hook.
 *
 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
 */
do_action('woocommerce_after_main_content');
?>

<?php
/**
 * woocommerce_sidebar hook.
 *
 * @hooked woocommerce_get_sidebar - 10
 */
/*if (!isset($args['ajax']) && !isset($_REQUEST['no_sidebar']))
    do_action('woocommerce_sidebar');
*/?>

<?php
if (!isset($args['ajax']))
    get_footer('shop');
?>
